import json
from http import HTTPStatus
from typing import Any, Dict, Optional, Union

import requests

from ... import errors
from ...models.list_projects_order import ListProjectsOrder
from ...models.list_projects_order_by import ListProjectsOrderBy
from ...models.list_projects_response_200 import ListProjectsResponse200
from ...models.list_projects_response_401 import ListProjectsResponse401
from ...models.list_projects_response_500 import ListProjectsResponse500
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    client: {},
    page: Union[Unset, None, int] = 1,
    duration: Union[Unset, None, int] = UNSET,
    order: Union[Unset, None, ListProjectsOrder] = ListProjectsOrder.DESC,
    order_by: Union[Unset, None, ListProjectsOrderBy] = ListProjectsOrderBy.ID,
    width: Union[Unset, None, str] = "100%",
    height: Union[Unset, None, str] = "auto",
    name: Union[Unset, None, str] = UNSET,
) -> Dict[str, Any]:
    url = "{}/api/v1/projects".format(client.base_url)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {}
    params["page"] = page

    params["duration"] = duration

    json_order: Union[Unset, None, str] = UNSET
    if not isinstance(order, Unset):
        json_order = order if order else None

    params["order"] = json_order

    json_order_by: Union[Unset, None, str] = UNSET
    if not isinstance(order_by, Unset):
        json_order_by = order_by if order_by else None

    params["orderBy"] = json_order_by

    params["width"] = width

    params["height"] = height

    params["name"] = name

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "method": "get",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "allow_redirects": client.follow_redirects,
        "params": params,
    }


def _parse_response(
    *, client: {}, response: None
) -> Optional[Union[ListProjectsResponse200, ListProjectsResponse401, ListProjectsResponse500]]:
    if response.status_code == HTTPStatus.OK:
        response_200 = ListProjectsResponse200.from_dict(json.loads(response.text))

        return response_200
    if response.status_code == HTTPStatus.UNAUTHORIZED:
        response_401 = ListProjectsResponse401.from_dict(json.loads(response.text))

        return response_401
    if response.status_code == HTTPStatus.INTERNAL_SERVER_ERROR:
        response_500 = ListProjectsResponse500.from_dict(json.loads(response.text))

        return response_500
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: {}, response: None, content: Optional[bytes] = None
) -> Response[Union[ListProjectsResponse200, ListProjectsResponse401, ListProjectsResponse500]]:
    parse = _parse_response(client=client, response=response)
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content if content is None else content,
        headers=response.headers,
        parsed=parse,
    )


def sync_detailed(
    *,
    client: {},
    page: Union[Unset, None, int] = 1,
    duration: Union[Unset, None, int] = UNSET,
    order: Union[Unset, None, ListProjectsOrder] = ListProjectsOrder.DESC,
    order_by: Union[Unset, None, ListProjectsOrderBy] = ListProjectsOrderBy.ID,
    width: Union[Unset, None, str] = "100%",
    height: Union[Unset, None, str] = "auto",
    name: Union[Unset, None, str] = UNSET,
):
    """List all projects.

     Returns a list of your projects. The projects are returned sorted by creation date, with the most
    recent projects appearing first. It is a paginated API and you can use the page parameter to fetch
    the next page of projects. The default page size is 10.

    Here is an example to list projects: using [API](https://github.com/Poll-The-People/customgpt-
    cookbook/blob/main/examples/List_all_projects_for_an_account_with_pagination.ipynb) and using our
    python [SDK](https://github.com/Poll-The-People/customgpt-
    cookbook/blob/main/examples/SDK_List_all_projects_using_pagination.ipynb).

    Args:
        page (Union[Unset, None, int]):  Default: 1. Example: 1.
        duration (Union[Unset, None, int]):
        order (Union[Unset, None, ListProjectsOrder]):  Default: ListProjectsOrder.DESC. Example:
            desc.
        order_by (Union[Unset, None, ListProjectsOrderBy]):  Default: ListProjectsOrderBy.ID.
            Example: id.
        width (Union[Unset, None, str]):  Default: '100%'. Example: 50rem.
        height (Union[Unset, None, str]):  Default: 'auto'. Example: 50rem.
        name (Union[Unset, None, str]):  Example: Sample project.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[ListProjectsResponse200, ListProjectsResponse401, ListProjectsResponse500]]
    """

    kwargs = _get_kwargs(
        client=client,
        page=page,
        duration=duration,
        order=order,
        order_by=order_by,
        width=width,
        height=height,
        name=name,
    )

    response = requests.request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: {},
    page: Union[Unset, None, int] = 1,
    duration: Union[Unset, None, int] = UNSET,
    order: Union[Unset, None, ListProjectsOrder] = ListProjectsOrder.DESC,
    order_by: Union[Unset, None, ListProjectsOrderBy] = ListProjectsOrderBy.ID,
    width: Union[Unset, None, str] = "100%",
    height: Union[Unset, None, str] = "auto",
    name: Union[Unset, None, str] = UNSET,
) -> Optional[Union[ListProjectsResponse200, ListProjectsResponse401, ListProjectsResponse500]]:
    """List all projects.

     Returns a list of your projects. The projects are returned sorted by creation date, with the most
    recent projects appearing first. It is a paginated API and you can use the page parameter to fetch
    the next page of projects. The default page size is 10.

    Here is an example to list projects: using [API](https://github.com/Poll-The-People/customgpt-
    cookbook/blob/main/examples/List_all_projects_for_an_account_with_pagination.ipynb) and using our
    python [SDK](https://github.com/Poll-The-People/customgpt-
    cookbook/blob/main/examples/SDK_List_all_projects_using_pagination.ipynb).

    Args:
        page (Union[Unset, None, int]):  Default: 1. Example: 1.
        duration (Union[Unset, None, int]):
        order (Union[Unset, None, ListProjectsOrder]):  Default: ListProjectsOrder.DESC. Example:
            desc.
        order_by (Union[Unset, None, ListProjectsOrderBy]):  Default: ListProjectsOrderBy.ID.
            Example: id.
        width (Union[Unset, None, str]):  Default: '100%'. Example: 50rem.
        height (Union[Unset, None, str]):  Default: 'auto'. Example: 50rem.
        name (Union[Unset, None, str]):  Example: Sample project.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[ListProjectsResponse200, ListProjectsResponse401, ListProjectsResponse500]
    """

    return sync_detailed(
        client=client,
        page=page,
        duration=duration,
        order=order,
        order_by=order_by,
        width=width,
        height=height,
        name=name,
    ).parsed


async def asyncio_detailed(
    *,
    client: {},
    page: Union[Unset, None, int] = 1,
    duration: Union[Unset, None, int] = UNSET,
    order: Union[Unset, None, ListProjectsOrder] = ListProjectsOrder.DESC,
    order_by: Union[Unset, None, ListProjectsOrderBy] = ListProjectsOrderBy.ID,
    width: Union[Unset, None, str] = "100%",
    height: Union[Unset, None, str] = "auto",
    name: Union[Unset, None, str] = UNSET,
) -> Response[Union[ListProjectsResponse200, ListProjectsResponse401, ListProjectsResponse500]]:

    kwargs = _get_kwargs(
        client=client,
        page=page,
        duration=duration,
        order=order,
        order_by=order_by,
        width=width,
        height=height,
        name=name,
    )

    response = requests.request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: {},
    page: Union[Unset, None, int] = 1,
    duration: Union[Unset, None, int] = UNSET,
    order: Union[Unset, None, ListProjectsOrder] = ListProjectsOrder.DESC,
    order_by: Union[Unset, None, ListProjectsOrderBy] = ListProjectsOrderBy.ID,
    width: Union[Unset, None, str] = "100%",
    height: Union[Unset, None, str] = "auto",
    name: Union[Unset, None, str] = UNSET,
) -> Optional[Union[ListProjectsResponse200, ListProjectsResponse401, ListProjectsResponse500]]:
    """List all projects.

     Returns a list of your projects. The projects are returned sorted by creation date, with the most
    recent projects appearing first. It is a paginated API and you can use the page parameter to fetch
    the next page of projects. The default page size is 10.

    Here is an example to list projects: using [API](https://github.com/Poll-The-People/customgpt-
    cookbook/blob/main/examples/List_all_projects_for_an_account_with_pagination.ipynb) and using our
    python [SDK](https://github.com/Poll-The-People/customgpt-
    cookbook/blob/main/examples/SDK_List_all_projects_using_pagination.ipynb).

    Args:
        page (Union[Unset, None, int]):  Default: 1. Example: 1.
        duration (Union[Unset, None, int]):
        order (Union[Unset, None, ListProjectsOrder]):  Default: ListProjectsOrder.DESC. Example:
            desc.
        order_by (Union[Unset, None, ListProjectsOrderBy]):  Default: ListProjectsOrderBy.ID.
            Example: id.
        width (Union[Unset, None, str]):  Default: '100%'. Example: 50rem.
        height (Union[Unset, None, str]):  Default: 'auto'. Example: 50rem.
        name (Union[Unset, None, str]):  Example: Sample project.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[ListProjectsResponse200, ListProjectsResponse401, ListProjectsResponse500]
    """

    return (
        await asyncio_detailed(
            client=client,
            page=page,
            duration=duration,
            order=order,
            order_by=order_by,
            width=width,
            height=height,
            name=name,
        )
    ).parsed



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.project_analytics_traffic_sources_item import ProjectAnalyticsTrafficSourcesItem


T = TypeVar("T", bound="ProjectAnalyticsTraffic")


@attr.s(auto_attribs=True)
class ProjectAnalyticsTraffic:
    """
    Attributes:
        sources (Union[Unset, List['ProjectAnalyticsTrafficSourcesItem']]):
    """

    sources: Union[Unset, List["ProjectAnalyticsTrafficSourcesItem"]] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        sources: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.sources, Unset):
            sources = []
            for sources_item_data in self.sources:
                sources_item = sources_item_data.to_dict()

                sources.append(sources_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if sources is not UNSET:
            for index, field_value in enumerate(sources):
                field_dict[f"sources[{index}]"] = field_value

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.project_analytics_traffic_sources_item import ProjectAnalyticsTrafficSourcesItem

        sources = []
        _sources = src_dict.get("sources")
        for sources_item_data in _sources or []:
            sources_item = ProjectAnalyticsTrafficSourcesItem.from_dict(sources_item_data)

            sources.append(sources_item)

        project_analytics_traffic = cls(
            sources=sources,
        )

        project_analytics_traffic.additional_properties = src_dict
        return project_analytics_traffic

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..types import UNSET, Unset

T = TypeVar("T", bound="GetProjectResponse200Data")


@attr.s(auto_attribs=True)
class GetProjectResponse200Data:
    """
    Attributes:
        id (Union[Unset, int]): Project ID Example: 1.
        project_name (Union[Unset, str]): Project name Example: My Project.
        sitemap_path (Union[Unset, str]): Project sitemap Example: https://www.example.com/sitemap.xml.
        is_chat_active (Union[Unset, bool]): Whether the chat bot is active or not Example: True.
        user_id (Union[Unset, int]): User ID of the project owner Example: 1.
        team_id (Union[Unset, int]): Team ID of the project owner Example: 1.
        created_at (Union[Unset, datetime.datetime]): Date and time when the project was created Default:
            isoparse('2023-05-08 13:06:55'). Example: 2021-01-01 00:00:00.
        updated_at (Union[Unset, datetime.datetime]): Date and time when the project was last updated Default:
            isoparse('2023-05-08 13:06:55'). Example: 2021-01-01 00:00:00.
        type (Union[Unset, GetProjectResponse200DataType]): Project type Default: GetProjectResponse200DataType.SITEMAP.
            Example: SITEMAP.
        is_shared (Union[Unset, bool]): Whether the project is shared or not Example: True.
        shareable_slug (Union[Unset, None, str]): Shareable slug that can be used to share the project Example:
            1234567890abcdef1234567890abcdef.
        shareable_link (Union[Unset, None, str]): Shareable link that can be used to share the project
        embed_code (Union[Unset, None, str]): Embed code that can be used to embed the project
        live_chat_code (Union[Unset, None, str]): Live chat code that can be used to embed the live chat
    """

    id: Union[Unset, int] = UNSET
    project_name: Union[Unset, str] = UNSET
    sitemap_path: Union[Unset, str] = UNSET
    is_chat_active: Union[Unset, bool] = False
    user_id: Union[Unset, int] = UNSET
    team_id: Union[Unset, int] = UNSET
    created_at: Union[Unset, datetime.datetime] = isoparse("2023-05-08 13:06:55")
    updated_at: Union[Unset, datetime.datetime] = isoparse("2023-05-08 13:06:55")
    type: Union[Unset, str] = UNSET
    is_shared: Union[Unset, bool] = False
    shareable_slug: Union[Unset, None, str] = UNSET
    shareable_link: Union[Unset, None, str] = UNSET
    embed_code: Union[Unset, None, str] = UNSET
    live_chat_code: Union[Unset, None, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        id = self.id
        project_name = self.project_name
        sitemap_path = self.sitemap_path
        is_chat_active = True if self.is_chat_active else False

        user_id = self.user_id
        team_id = self.team_id
        created_at: Union[Unset, str] = UNSET
        if not isinstance(self.created_at, Unset):
            created_at = self.created_at.isoformat()

        updated_at: Union[Unset, str] = UNSET
        if not isinstance(self.updated_at, Unset):
            updated_at = self.updated_at.isoformat()

        type: Union[Unset, str] = UNSET
        if not isinstance(self.type, Unset):
            type = self.type

        is_shared = True if self.is_shared else False

        shareable_slug = self.shareable_slug
        shareable_link = self.shareable_link
        embed_code = self.embed_code
        live_chat_code = self.live_chat_code

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if id is not UNSET:
            field_dict["id"] = id
        if project_name is not UNSET:
            field_dict["project_name"] = project_name
        if sitemap_path is not UNSET:
            field_dict["sitemap_path"] = sitemap_path
        if is_chat_active is not UNSET:
            field_dict["is_chat_active"] = is_chat_active
        if user_id is not UNSET:
            field_dict["user_id"] = user_id
        if team_id is not UNSET:
            field_dict["team_id"] = team_id
        if created_at is not UNSET:
            field_dict["created_at"] = created_at
        if updated_at is not UNSET:
            field_dict["updated_at"] = updated_at
        if type is not UNSET:
            field_dict["type"] = type
        if is_shared is not UNSET:
            field_dict["is_shared"] = is_shared
        if shareable_slug is not UNSET:
            field_dict["shareable_slug"] = shareable_slug
        if shareable_link is not UNSET:
            field_dict["shareable_link"] = shareable_link
        if embed_code is not UNSET:
            field_dict["embed_code"] = embed_code
        if live_chat_code is not UNSET:
            field_dict["live_chat_code"] = live_chat_code

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        id = src_dict.get("id")

        project_name = src_dict.get("project_name")

        sitemap_path = src_dict.get("sitemap_path")

        is_chat_active = src_dict.get("is_chat_active")

        user_id = src_dict.get("user_id")

        team_id = src_dict.get("team_id")

        _created_at = src_dict.get("created_at")
        created_at: Union[Unset, datetime.datetime]
        if isinstance(_created_at, Unset):
            created_at = UNSET
        else:
            created_at = isoparse(_created_at)

        _updated_at = src_dict.get("updated_at")
        updated_at: Union[Unset, datetime.datetime]
        if isinstance(_updated_at, Unset):
            updated_at = UNSET
        else:
            updated_at = isoparse(_updated_at)

        type = src_dict.get("type")

        is_shared = src_dict.get("is_shared")

        shareable_slug = src_dict.get("shareable_slug")

        shareable_link = src_dict.get("shareable_link")

        embed_code = src_dict.get("embed_code")

        live_chat_code = src_dict.get("live_chat_code")

        get_project_response_200_data = cls(
            id=id,
            project_name=project_name,
            sitemap_path=sitemap_path,
            is_chat_active=is_chat_active,
            user_id=user_id,
            team_id=team_id,
            created_at=created_at,
            updated_at=updated_at,
            type=type,
            is_shared=is_shared,
            shareable_slug=shareable_slug,
            shareable_link=shareable_link,
            embed_code=embed_code,
            live_chat_code=live_chat_code,
        )

        get_project_response_200_data.additional_properties = src_dict
        return get_project_response_200_data

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from io import BytesIO
from typing import Any, Dict, List, Tuple, Type, TypeVar, Union, cast

import attr

from ..types import UNSET, File, FileJsonType, Unset

T = TypeVar("T", bound="UpdateProjectSettingsMultipartData")


@attr.s(auto_attribs=True)
class UpdateProjectSettingsMultipartData:
    """
    Attributes:
        chat_bot_avatar (Union[Unset, File]): This is the avatar that is shown in the bot response. You can make it a
            profile picture or your company logo. Example: avatar.png.
        chat_bot_bg (Union[Unset, File]): This is the background image shown in the bot conversations widget. You can
            change it to a company logo or background image. Example: bg.png.
        default_prompt (Union[Unset, str]): This is the default prompt shown to the user. You can customize this for
            your company or client. Example: How can I help you?.
        example_questions (Union[Unset, List[str]]): These are example questions shown to guide the bot users. You can
            create customized questions to suit your company or client needs.
        response_source (Union[Unset, UpdateProjectSettingsMultipartDataResponseSource]): By default, we ask ChatGPT to
            use only your content in its response (recommended). If you wish ChatGPT to improvise and use its own
            knowledgebase as well, you can select "My Content + ChatGPT" Example: own_content.
        chatbot_msg_lang (Union[Unset, UpdateProjectSettingsMultipartDataChatbotMsgLang]): By default, the chatbot
            messages like 'Ask Me Anything' are in English. You can customize this to your preferred language. Please note:
            This setting does not control what language ChatGPT responds in. That is controlled by the user's question. So a
            user asking in Portuguese, will most likely get a response from ChatGPT in Portuguese. Example: en.
        chatbot_color (Union[Unset, str]): Color of the chatbot in hex format Example: #000000.
        chatbot_toolbar_color (Union[Unset, str]): Color of the chatbot toolbar in hex format Example: #000000.
        persona_instructions (Union[Unset, None, str]): Customize your chatbot behavior by adjusting the system
            parameter to control its personality traits  and role. Example: You are a custom chatbot assistant called
            CustomGPT.ai, a friendly lawyer who answers questions based on the given context..
        citations_answer_source_label_msg (Union[Unset, None, str]): This is the message shown to indicate where the
            response came from. You can customize this message based on your business or language. Example: Where did this
            answer come from?.
        citations_sources_label_msg (Union[Unset, None, str]): This is the message shown for the Sources label.  You can
            customize this message based on your business or language. Example: Sources.
        hang_in_there_msg (Union[Unset, None, str]): This is the message shown when the bot is thinking and waiting to
            answer. You can customize this message based on your tone, personality or language. Example: Hang in there! I'm
            thinking...
        chatbot_siesta_msg (Union[Unset, None, str]): This is the message shown when the bot has encountered a problem
            or error. You can customize this message based on your tone, personality or language. Example: Oops! The chat
            bot is taking a siesta. This usually happens when OpenAI is down! Please try again later..
        is_loading_indicator_enabled (Union[Unset, None, bool]): Show animated loading indicator while waiting for a
            response from the chatbot Default: True. Example: True.
        enable_citations (Union[Unset, None, UpdateProjectSettingsMultipartDataEnableCitations]): Each chatbot response
            shows an option for the user to see the sources/citations from your content from which the response was
            generated. Default: UpdateProjectSettingsMultipartDataEnableCitations.VALUE_3. Example: 3.
        enable_feedbacks (Union[Unset, None, bool]): Each chatbot response shows an thumbs up/down for the user to left
            own feedback. Default: True. Example: True.
        citations_view_type (Union[Unset, None, UpdateProjectSettingsMultipartDataCitationsViewType]): Control how
            citations are shown. By default, the user can initiate to see the citations. You can choose to have it "Auto
            Shown" or "Auto Hide" Default: UpdateProjectSettingsMultipartDataCitationsViewType.USER. Example: user.
        no_answer_message (Union[Unset, None, str]): This is the message shown when the bot cannot answer. You can
            customize it to a message asking the user to contact customer support or leave their email / phone. Default:
            "I'm sorry, I don't know the answer". Example: Sorry, I don't have an answer for that..
        ending_message (Union[Unset, None, str]): You can instruct ChatGPT to end every response with some text like
            asking "Please email us for further support" (Not recommended for most use cases) Example: Please email us for
            further support.
        remove_branding (Union[Unset, None, bool]): Controls what branding is shown at the bottom of the chatbot.
        enable_recaptcha_for_public_chatbots (Union[Unset, None, bool]): Should we check messages from guests with
            Recaptcha when your chatbot is publicly available (i.e. shared or embedded).
        chatbot_model (Union[Unset, None, UpdateProjectSettingsMultipartDataChatbotModel]): This is the model used by
            the chatbot. You can choose a different model to suit your needs. Example: gpt-4.
        is_selling_enabled (Union[Unset, None, bool]): Enable selling of chatbot for monetization
    """

    chat_bot_avatar: Union[Unset, File] = UNSET
    chat_bot_bg: Union[Unset, File] = UNSET
    default_prompt: Union[Unset, str] = UNSET
    example_questions: Union[Unset, List[str]] = UNSET
    response_source: Union[Unset, str] = UNSET
    chatbot_msg_lang: Union[Unset, str] = UNSET
    chatbot_color: Union[Unset, str] = UNSET
    chatbot_toolbar_color: Union[Unset, str] = UNSET
    persona_instructions: Union[Unset, None, str] = UNSET
    citations_answer_source_label_msg: Union[Unset, None, str] = UNSET
    citations_sources_label_msg: Union[Unset, None, str] = UNSET
    hang_in_there_msg: Union[Unset, None, str] = UNSET
    chatbot_siesta_msg: Union[Unset, None, str] = UNSET
    is_loading_indicator_enabled: Union[Unset, None, bool] = True
    enable_citations: Union[Unset, str] = UNSET
    enable_feedbacks: Union[Unset, None, bool] = True
    citations_view_type: Union[Unset, str] = UNSET
    no_answer_message: Union[Unset, None, str] = "I'm sorry, I don't know the answer"
    ending_message: Union[Unset, None, str] = UNSET
    remove_branding: Union[Unset, None, bool] = False
    enable_recaptcha_for_public_chatbots: Union[Unset, None, bool] = False
    chatbot_model: Union[Unset, str] = UNSET
    is_selling_enabled: Union[Unset, None, bool] = False
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        chat_bot_avatar: Union[Unset, FileJsonType] = UNSET
        if not isinstance(self.chat_bot_avatar, Unset):
            chat_bot_avatar = self.chat_bot_avatar.to_tuple()

        chat_bot_bg: Union[Unset, FileJsonType] = UNSET
        if not isinstance(self.chat_bot_bg, Unset):
            chat_bot_bg = self.chat_bot_bg.to_tuple()

        default_prompt = self.default_prompt
        example_questions: Union[Unset, List[str]] = UNSET
        if not isinstance(self.example_questions, Unset):
            example_questions = self.example_questions

        response_source: Union[Unset, str] = UNSET
        if not isinstance(self.response_source, Unset):
            response_source = self.response_source

        chatbot_msg_lang: Union[Unset, str] = UNSET
        if not isinstance(self.chatbot_msg_lang, Unset):
            chatbot_msg_lang = self.chatbot_msg_lang

        chatbot_color = self.chatbot_color
        chatbot_toolbar_color = self.chatbot_toolbar_color
        persona_instructions = self.persona_instructions
        citations_answer_source_label_msg = self.citations_answer_source_label_msg
        citations_sources_label_msg = self.citations_sources_label_msg
        hang_in_there_msg = self.hang_in_there_msg
        chatbot_siesta_msg = self.chatbot_siesta_msg
        is_loading_indicator_enabled = True if self.is_loading_indicator_enabled else False

        enable_citations: Union[Unset, None, int] = UNSET
        if not isinstance(self.enable_citations, Unset):
            enable_citations = self.enable_citations if self.enable_citations else None

        enable_feedbacks = True if self.enable_feedbacks else False

        citations_view_type: Union[Unset, None, str] = UNSET
        if not isinstance(self.citations_view_type, Unset):
            citations_view_type = self.citations_view_type if self.citations_view_type else None

        no_answer_message = self.no_answer_message
        ending_message = self.ending_message
        remove_branding = True if self.remove_branding else False

        enable_recaptcha_for_public_chatbots = True if self.enable_recaptcha_for_public_chatbots else False

        chatbot_model: Union[Unset, None, str] = UNSET
        if not isinstance(self.chatbot_model, Unset):
            chatbot_model = self.chatbot_model if self.chatbot_model else None

        is_selling_enabled = True if self.is_selling_enabled else False

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if chat_bot_avatar is not UNSET:
            field_dict["chat_bot_avatar"] = chat_bot_avatar
        if chat_bot_bg is not UNSET:
            field_dict["chat_bot_bg"] = chat_bot_bg
        if default_prompt is not UNSET:
            field_dict["default_prompt"] = default_prompt
        if example_questions is not UNSET:
            for index, field_value in enumerate(example_questions):
                field_dict[f"example_questions[{index}]"] = field_value
        if response_source is not UNSET:
            field_dict["response_source"] = response_source
        if chatbot_msg_lang is not UNSET:
            field_dict["chatbot_msg_lang"] = chatbot_msg_lang
        if chatbot_color is not UNSET:
            field_dict["chatbot_color"] = chatbot_color
        if chatbot_toolbar_color is not UNSET:
            field_dict["chatbot_toolbar_color"] = chatbot_toolbar_color
        if persona_instructions is not UNSET:
            field_dict["persona_instructions"] = persona_instructions
        if citations_answer_source_label_msg is not UNSET:
            field_dict["citations_answer_source_label_msg"] = citations_answer_source_label_msg
        if citations_sources_label_msg is not UNSET:
            field_dict["citations_sources_label_msg"] = citations_sources_label_msg
        if hang_in_there_msg is not UNSET:
            field_dict["hang_in_there_msg"] = hang_in_there_msg
        if chatbot_siesta_msg is not UNSET:
            field_dict["chatbot_siesta_msg"] = chatbot_siesta_msg
        if is_loading_indicator_enabled is not UNSET:
            field_dict["is_loading_indicator_enabled"] = is_loading_indicator_enabled
        if enable_citations is not UNSET:
            field_dict["enable_citations"] = enable_citations
        if enable_feedbacks is not UNSET:
            field_dict["enable_feedbacks"] = enable_feedbacks
        if citations_view_type is not UNSET:
            field_dict["citations_view_type"] = citations_view_type
        if no_answer_message is not UNSET:
            field_dict["no_answer_message"] = no_answer_message
        if ending_message is not UNSET:
            field_dict["ending_message"] = ending_message
        if remove_branding is not UNSET:
            field_dict["remove_branding"] = remove_branding
        if enable_recaptcha_for_public_chatbots is not UNSET:
            field_dict["enable_recaptcha_for_public_chatbots"] = enable_recaptcha_for_public_chatbots
        if chatbot_model is not UNSET:
            field_dict["chatbot_model"] = chatbot_model
        if is_selling_enabled is not UNSET:
            field_dict["is_selling_enabled"] = is_selling_enabled

        return field_dict

    def to_multipart(self) -> Dict[str, Any]:
        chat_bot_avatar: Union[Unset, FileJsonType] = UNSET
        if not isinstance(self.chat_bot_avatar, Unset):
            chat_bot_avatar = self.chat_bot_avatar.to_tuple()

        chat_bot_bg: Union[Unset, FileJsonType] = UNSET
        if not isinstance(self.chat_bot_bg, Unset):
            chat_bot_bg = self.chat_bot_bg.to_tuple()

        default_prompt = (
            self.default_prompt
            if isinstance(self.default_prompt, Unset)
            else (None, str(self.default_prompt).encode(), "text/plain")
        )
        example_questions: Union[Unset, Tuple[None, bytes, str]] = UNSET
        if not isinstance(self.example_questions, Unset):
            self.example_questions
            example_questions = []
            for index, value in enumerate(self.example_questions):
                field_value = (None, str(value).encode(), "text/plain")
                example_questions.append(field_value)

        response_source: Union[Unset, Tuple[None, bytes, str]] = UNSET
        if not isinstance(self.response_source, Unset):
            response_source = (None, str(self.response_source).encode(), "text/plain")

        chatbot_msg_lang: Union[Unset, Tuple[None, bytes, str]] = UNSET
        if not isinstance(self.chatbot_msg_lang, Unset):
            chatbot_msg_lang = (None, str(self.chatbot_msg_lang).encode(), "text/plain")

        chatbot_color = (
            self.chatbot_color
            if isinstance(self.chatbot_color, Unset)
            else (None, str(self.chatbot_color).encode(), "text/plain")
        )
        chatbot_toolbar_color = (
            self.chatbot_toolbar_color
            if isinstance(self.chatbot_toolbar_color, Unset)
            else (None, str(self.chatbot_toolbar_color).encode(), "text/plain")
        )
        persona_instructions = (
            self.persona_instructions
            if isinstance(self.persona_instructions, Unset)
            else (None, str(self.persona_instructions).encode(), "text/plain")
        )
        citations_answer_source_label_msg = (
            self.citations_answer_source_label_msg
            if isinstance(self.citations_answer_source_label_msg, Unset)
            else (None, str(self.citations_answer_source_label_msg).encode(), "text/plain")
        )
        citations_sources_label_msg = (
            self.citations_sources_label_msg
            if isinstance(self.citations_sources_label_msg, Unset)
            else (None, str(self.citations_sources_label_msg).encode(), "text/plain")
        )
        hang_in_there_msg = (
            self.hang_in_there_msg
            if isinstance(self.hang_in_there_msg, Unset)
            else (None, str(self.hang_in_there_msg).encode(), "text/plain")
        )
        chatbot_siesta_msg = (
            self.chatbot_siesta_msg
            if isinstance(self.chatbot_siesta_msg, Unset)
            else (None, str(self.chatbot_siesta_msg).encode(), "text/plain")
        )
        is_loading_indicator_enabled = (
            self.is_loading_indicator_enabled
            if isinstance(self.is_loading_indicator_enabled, Unset)
            else (None, str(self.is_loading_indicator_enabled).lower().encode(), "text/plain")
        )

        enable_citations: Union[Unset, Tuple[None, bytes, str]] = UNSET
        if not isinstance(self.enable_citations, Unset):
            enable_citations = (
                (None, str(self.enable_citations).encode(), "text/plain") if self.enable_citations else None
            )

        enable_feedbacks = (
            self.enable_feedbacks
            if isinstance(self.enable_feedbacks, Unset)
            else (None, str(self.enable_feedbacks).lower().encode(), "text/plain")
        )

        citations_view_type: Union[Unset, Tuple[None, bytes, str]] = UNSET
        if not isinstance(self.citations_view_type, Unset):
            citations_view_type = (
                (None, str(self.citations_view_type).encode(), "text/plain") if self.citations_view_type else None
            )

        no_answer_message = (
            self.no_answer_message
            if isinstance(self.no_answer_message, Unset)
            else (None, str(self.no_answer_message).encode(), "text/plain")
        )
        ending_message = (
            self.ending_message
            if isinstance(self.ending_message, Unset)
            else (None, str(self.ending_message).encode(), "text/plain")
        )
        remove_branding = (
            self.remove_branding
            if isinstance(self.remove_branding, Unset)
            else (None, str(self.remove_branding).lower().encode(), "text/plain")
        )

        enable_recaptcha_for_public_chatbots = (
            self.enable_recaptcha_for_public_chatbots
            if isinstance(self.enable_recaptcha_for_public_chatbots, Unset)
            else (None, str(self.enable_recaptcha_for_public_chatbots).lower().encode(), "text/plain")
        )

        chatbot_model: Union[Unset, Tuple[None, bytes, str]] = UNSET
        if not isinstance(self.chatbot_model, Unset):
            chatbot_model = (None, str(self.chatbot_model).encode(), "text/plain") if self.chatbot_model else None

        is_selling_enabled = (
            self.is_selling_enabled
            if isinstance(self.is_selling_enabled, Unset)
            else (None, str(self.is_selling_enabled).lower().encode(), "text/plain")
        )

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {key: (None, str(value).encode(), "text/plain") for key, value in self.additional_properties.items()}
        )
        field_dict.update({})
        if chat_bot_avatar is not UNSET:
            field_dict["chat_bot_avatar"] = chat_bot_avatar
        if chat_bot_bg is not UNSET:
            field_dict["chat_bot_bg"] = chat_bot_bg
        if default_prompt is not UNSET:
            field_dict["default_prompt"] = default_prompt
        if example_questions is not UNSET:
            for index, field_value in enumerate(example_questions):
                field_dict[f"example_questions[{index}]"] = field_value
        if response_source is not UNSET:
            field_dict["response_source"] = response_source
        if chatbot_msg_lang is not UNSET:
            field_dict["chatbot_msg_lang"] = chatbot_msg_lang
        if chatbot_color is not UNSET:
            field_dict["chatbot_color"] = chatbot_color
        if chatbot_toolbar_color is not UNSET:
            field_dict["chatbot_toolbar_color"] = chatbot_toolbar_color
        if persona_instructions is not UNSET:
            field_dict["persona_instructions"] = persona_instructions
        if citations_answer_source_label_msg is not UNSET:
            field_dict["citations_answer_source_label_msg"] = citations_answer_source_label_msg
        if citations_sources_label_msg is not UNSET:
            field_dict["citations_sources_label_msg"] = citations_sources_label_msg
        if hang_in_there_msg is not UNSET:
            field_dict["hang_in_there_msg"] = hang_in_there_msg
        if chatbot_siesta_msg is not UNSET:
            field_dict["chatbot_siesta_msg"] = chatbot_siesta_msg
        if is_loading_indicator_enabled is not UNSET:
            field_dict["is_loading_indicator_enabled"] = is_loading_indicator_enabled
        if enable_citations is not UNSET:
            field_dict["enable_citations"] = enable_citations
        if enable_feedbacks is not UNSET:
            field_dict["enable_feedbacks"] = enable_feedbacks
        if citations_view_type is not UNSET:
            field_dict["citations_view_type"] = citations_view_type
        if no_answer_message is not UNSET:
            field_dict["no_answer_message"] = no_answer_message
        if ending_message is not UNSET:
            field_dict["ending_message"] = ending_message
        if remove_branding is not UNSET:
            field_dict["remove_branding"] = remove_branding
        if enable_recaptcha_for_public_chatbots is not UNSET:
            field_dict["enable_recaptcha_for_public_chatbots"] = enable_recaptcha_for_public_chatbots
        if chatbot_model is not UNSET:
            field_dict["chatbot_model"] = chatbot_model
        if is_selling_enabled is not UNSET:
            field_dict["is_selling_enabled"] = is_selling_enabled

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        _chat_bot_avatar = src_dict.get("chat_bot_avatar")
        chat_bot_avatar: Union[Unset, File]
        if isinstance(_chat_bot_avatar, Unset):
            chat_bot_avatar = UNSET
        else:
            chat_bot_avatar = File(payload=BytesIO(_chat_bot_avatar))

        _chat_bot_bg = src_dict.get("chat_bot_bg")
        chat_bot_bg: Union[Unset, File]
        if isinstance(_chat_bot_bg, Unset):
            chat_bot_bg = UNSET
        else:
            chat_bot_bg = File(payload=BytesIO(_chat_bot_bg))

        default_prompt = src_dict.get("default_prompt")

        example_questions = cast(List[str], src_dict.get("example_questions"))

        response_source = src_dict.get("response_source")

        chatbot_msg_lang = src_dict.get("chatbot_msg_lang")

        chatbot_color = src_dict.get("chatbot_color")

        chatbot_toolbar_color = src_dict.get("chatbot_toolbar_color")

        persona_instructions = src_dict.get("persona_instructions")

        citations_answer_source_label_msg = src_dict.get("citations_answer_source_label_msg")

        citations_sources_label_msg = src_dict.get("citations_sources_label_msg")

        hang_in_there_msg = src_dict.get("hang_in_there_msg")

        chatbot_siesta_msg = src_dict.get("chatbot_siesta_msg")

        is_loading_indicator_enabled = src_dict.get("is_loading_indicator_enabled")

        enable_citations = src_dict.get("enable_citations")

        enable_feedbacks = src_dict.get("enable_feedbacks")

        citations_view_type = src_dict.get("citations_view_type")

        no_answer_message = src_dict.get("no_answer_message")

        ending_message = src_dict.get("ending_message")

        remove_branding = src_dict.get("remove_branding")

        enable_recaptcha_for_public_chatbots = src_dict.get("enable_recaptcha_for_public_chatbots")

        chatbot_model = src_dict.get("chatbot_model")

        is_selling_enabled = src_dict.get("is_selling_enabled")

        update_project_settings_multipart_data = cls(
            chat_bot_avatar=chat_bot_avatar,
            chat_bot_bg=chat_bot_bg,
            default_prompt=default_prompt,
            example_questions=example_questions,
            response_source=response_source,
            chatbot_msg_lang=chatbot_msg_lang,
            chatbot_color=chatbot_color,
            chatbot_toolbar_color=chatbot_toolbar_color,
            persona_instructions=persona_instructions,
            citations_answer_source_label_msg=citations_answer_source_label_msg,
            citations_sources_label_msg=citations_sources_label_msg,
            hang_in_there_msg=hang_in_there_msg,
            chatbot_siesta_msg=chatbot_siesta_msg,
            is_loading_indicator_enabled=is_loading_indicator_enabled,
            enable_citations=enable_citations,
            enable_feedbacks=enable_feedbacks,
            citations_view_type=citations_view_type,
            no_answer_message=no_answer_message,
            ending_message=ending_message,
            remove_branding=remove_branding,
            enable_recaptcha_for_public_chatbots=enable_recaptcha_for_public_chatbots,
            chatbot_model=chatbot_model,
            is_selling_enabled=is_selling_enabled,
        )

        update_project_settings_multipart_data.additional_properties = src_dict
        return update_project_settings_multipart_data

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import json
from http import HTTPStatus
from typing import Any, Dict, Optional, Union

import requests

from ... import errors
from ...models.delete_project_response_200 import DeleteProjectResponse200
from ...models.delete_project_response_400 import DeleteProjectResponse400
from ...models.delete_project_response_401 import DeleteProjectResponse401
from ...models.delete_project_response_404 import DeleteProjectResponse404
from ...models.delete_project_response_500 import DeleteProjectResponse500
from ...types import Response


def _get_kwargs(
    project_id: int,
    *,
    client: {},
) -> Dict[str, Any]:
    url = "{}/api/v1/projects/{projectId}".format(client.base_url, projectId=project_id)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    return {
        "method": "delete",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "allow_redirects": client.follow_redirects,
    }


def _parse_response(*, client: {}, response: None) -> Optional[
    Union[
        DeleteProjectResponse200,
        DeleteProjectResponse400,
        DeleteProjectResponse401,
        DeleteProjectResponse404,
        DeleteProjectResponse500,
    ]
]:
    if response.status_code == HTTPStatus.OK:
        response_200 = DeleteProjectResponse200.from_dict(json.loads(response.text))

        return response_200
    if response.status_code == HTTPStatus.BAD_REQUEST:
        response_400 = DeleteProjectResponse400.from_dict(json.loads(response.text))

        return response_400
    if response.status_code == HTTPStatus.UNAUTHORIZED:
        response_401 = DeleteProjectResponse401.from_dict(json.loads(response.text))

        return response_401
    if response.status_code == HTTPStatus.NOT_FOUND:
        response_404 = DeleteProjectResponse404.from_dict(json.loads(response.text))

        return response_404
    if response.status_code == HTTPStatus.INTERNAL_SERVER_ERROR:
        response_500 = DeleteProjectResponse500.from_dict(json.loads(response.text))

        return response_500
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(*, client: {}, response: None, content: Optional[bytes] = None) -> Response[
    Union[
        DeleteProjectResponse200,
        DeleteProjectResponse400,
        DeleteProjectResponse401,
        DeleteProjectResponse404,
        DeleteProjectResponse500,
    ]
]:
    parse = _parse_response(client=client, response=response)
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content if content is None else content,
        headers=response.headers,
        parsed=parse,
    )


def sync_detailed(
    project_id: int,
    *,
    client: {},
):
    """Delete a certain project.

     Delete a project by its unique project ID. This endpoint allows you to remove an existing project
    from the system based on its ID.
    Here is an example to delete a project: [API](https://github.com/Poll-The-People/customgpt-
    cookbook/blob/main/examples/Delete_a_project.ipynb) [SDK](https://github.com/Poll-The-
    People/customgpt-cookbook/blob/main/examples/SDK_Delete_a_project.ipynb).

    Args:
        project_id (int):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[DeleteProjectResponse200, DeleteProjectResponse400, DeleteProjectResponse401, DeleteProjectResponse404, DeleteProjectResponse500]]
    """

    kwargs = _get_kwargs(
        project_id=project_id,
        client=client,
    )

    response = requests.request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    project_id: int,
    *,
    client: {},
) -> Optional[
    Union[
        DeleteProjectResponse200,
        DeleteProjectResponse400,
        DeleteProjectResponse401,
        DeleteProjectResponse404,
        DeleteProjectResponse500,
    ]
]:
    """Delete a certain project.

     Delete a project by its unique project ID. This endpoint allows you to remove an existing project
    from the system based on its ID.
    Here is an example to delete a project: [API](https://github.com/Poll-The-People/customgpt-
    cookbook/blob/main/examples/Delete_a_project.ipynb) [SDK](https://github.com/Poll-The-
    People/customgpt-cookbook/blob/main/examples/SDK_Delete_a_project.ipynb).

    Args:
        project_id (int):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[DeleteProjectResponse200, DeleteProjectResponse400, DeleteProjectResponse401, DeleteProjectResponse404, DeleteProjectResponse500]
    """

    return sync_detailed(
        project_id=project_id,
        client=client,
    ).parsed


async def asyncio_detailed(
    project_id: int,
    *,
    client: {},
) -> Response[
    Union[
        DeleteProjectResponse200,
        DeleteProjectResponse400,
        DeleteProjectResponse401,
        DeleteProjectResponse404,
        DeleteProjectResponse500,
    ]
]:

    kwargs = _get_kwargs(
        project_id=project_id,
        client=client,
    )

    response = requests.request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


async def asyncio(
    project_id: int,
    *,
    client: {},
) -> Optional[
    Union[
        DeleteProjectResponse200,
        DeleteProjectResponse400,
        DeleteProjectResponse401,
        DeleteProjectResponse404,
        DeleteProjectResponse500,
    ]
]:
    """Delete a certain project.

     Delete a project by its unique project ID. This endpoint allows you to remove an existing project
    from the system based on its ID.
    Here is an example to delete a project: [API](https://github.com/Poll-The-People/customgpt-
    cookbook/blob/main/examples/Delete_a_project.ipynb) [SDK](https://github.com/Poll-The-
    People/customgpt-cookbook/blob/main/examples/SDK_Delete_a_project.ipynb).

    Args:
        project_id (int):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[DeleteProjectResponse200, DeleteProjectResponse400, DeleteProjectResponse401, DeleteProjectResponse404, DeleteProjectResponse500]
    """

    return (
        await asyncio_detailed(
            project_id=project_id,
            client=client,
        )
    ).parsed



import json
from http import HTTPStatus
from typing import Any, Dict, Optional, Union

import requests

from ... import errors
from ...models.messages_conversation_order import MessagesConversationOrder
from ...models.messages_conversation_response_200 import MessagesConversationResponse200
from ...models.messages_conversation_response_400 import MessagesConversationResponse400
from ...models.messages_conversation_response_401 import MessagesConversationResponse401
from ...models.messages_conversation_response_404 import MessagesConversationResponse404
from ...models.messages_conversation_response_500 import MessagesConversationResponse500
from ...types import UNSET, Response, Unset


def _get_kwargs(
    project_id: int,
    session_id: str,
    *,
    client: {},
    page: Union[Unset, None, int] = 1,
    order: Union[Unset, None, MessagesConversationOrder] = MessagesConversationOrder.DESC,
) -> Dict[str, Any]:
    url = "{}/api/v1/projects/{projectId}/conversations/{sessionId}/messages".format(
        client.base_url, projectId=project_id, sessionId=session_id
    )

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {}
    params["page"] = page

    json_order: Union[Unset, None, str] = UNSET
    if not isinstance(order, Unset):
        json_order = order if order else None

    params["order"] = json_order

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "method": "get",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "allow_redirects": client.follow_redirects,
        "params": params,
    }


def _parse_response(*, client: {}, response: None) -> Optional[
    Union[
        MessagesConversationResponse200,
        MessagesConversationResponse400,
        MessagesConversationResponse401,
        MessagesConversationResponse404,
        MessagesConversationResponse500,
    ]
]:
    if response.status_code == HTTPStatus.OK:
        response_200 = MessagesConversationResponse200.from_dict(json.loads(response.text))

        return response_200
    if response.status_code == HTTPStatus.BAD_REQUEST:
        response_400 = MessagesConversationResponse400.from_dict(json.loads(response.text))

        return response_400
    if response.status_code == HTTPStatus.UNAUTHORIZED:
        response_401 = MessagesConversationResponse401.from_dict(json.loads(response.text))

        return response_401
    if response.status_code == HTTPStatus.NOT_FOUND:
        response_404 = MessagesConversationResponse404.from_dict(json.loads(response.text))

        return response_404
    if response.status_code == HTTPStatus.INTERNAL_SERVER_ERROR:
        response_500 = MessagesConversationResponse500.from_dict(json.loads(response.text))

        return response_500
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(*, client: {}, response: None, content: Optional[bytes] = None) -> Response[
    Union[
        MessagesConversationResponse200,
        MessagesConversationResponse400,
        MessagesConversationResponse401,
        MessagesConversationResponse404,
        MessagesConversationResponse500,
    ]
]:
    parse = _parse_response(client=client, response=response)
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content if content is None else content,
        headers=response.headers,
        parsed=parse,
    )


def sync_detailed(
    project_id: int,
    session_id: str,
    *,
    client: {},
    page: Union[Unset, None, int] = 1,
    order: Union[Unset, None, MessagesConversationOrder] = MessagesConversationOrder.DESC,
):
    """Retrieve messages that have been sent in a conversation.

     Retrieve all messages sent within a conversation of a project identified by its unique projectId and
    sessionId. This endpoint allows you to retrieve a collection of messages exchanged in a specific
    conversation. Messages contain the content, timestamps, and other relevant information shared during
    the course of the conversation. By providing the projectId and sessionId, you can access all the
    messages associated with that particular conversation within the project context.
    Here is an example to retrieve messages of a conversation: [API](https://github.com/Poll-The-
    People/customgpt-cookbook/blob/main/examples/Retrieve_messages_for_a_conversation.ipynb)
    [SDK](https://github.com/Poll-The-People/customgpt-
    cookbook/blob/main/examples/SDK_Retrieve_Messages_of_conversation.ipynb).

    Args:
        project_id (int):  Example: 1.
        session_id (str):  Example: 1.
        page (Union[Unset, None, int]):  Default: 1.
        order (Union[Unset, None, MessagesConversationOrder]):  Default:
            MessagesConversationOrder.DESC. Example: desc.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[MessagesConversationResponse200, MessagesConversationResponse400, MessagesConversationResponse401, MessagesConversationResponse404, MessagesConversationResponse500]]
    """

    kwargs = _get_kwargs(
        project_id=project_id,
        session_id=session_id,
        client=client,
        page=page,
        order=order,
    )

    response = requests.request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    project_id: int,
    session_id: str,
    *,
    client: {},
    page: Union[Unset, None, int] = 1,
    order: Union[Unset, None, MessagesConversationOrder] = MessagesConversationOrder.DESC,
) -> Optional[
    Union[
        MessagesConversationResponse200,
        MessagesConversationResponse400,
        MessagesConversationResponse401,
        MessagesConversationResponse404,
        MessagesConversationResponse500,
    ]
]:
    """Retrieve messages that have been sent in a conversation.

     Retrieve all messages sent within a conversation of a project identified by its unique projectId and
    sessionId. This endpoint allows you to retrieve a collection of messages exchanged in a specific
    conversation. Messages contain the content, timestamps, and other relevant information shared during
    the course of the conversation. By providing the projectId and sessionId, you can access all the
    messages associated with that particular conversation within the project context.
    Here is an example to retrieve messages of a conversation: [API](https://github.com/Poll-The-
    People/customgpt-cookbook/blob/main/examples/Retrieve_messages_for_a_conversation.ipynb)
    [SDK](https://github.com/Poll-The-People/customgpt-
    cookbook/blob/main/examples/SDK_Retrieve_Messages_of_conversation.ipynb).

    Args:
        project_id (int):  Example: 1.
        session_id (str):  Example: 1.
        page (Union[Unset, None, int]):  Default: 1.
        order (Union[Unset, None, MessagesConversationOrder]):  Default:
            MessagesConversationOrder.DESC. Example: desc.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[MessagesConversationResponse200, MessagesConversationResponse400, MessagesConversationResponse401, MessagesConversationResponse404, MessagesConversationResponse500]
    """

    return sync_detailed(
        project_id=project_id,
        session_id=session_id,
        client=client,
        page=page,
        order=order,
    ).parsed


async def asyncio_detailed(
    project_id: int,
    session_id: str,
    *,
    client: {},
    page: Union[Unset, None, int] = 1,
    order: Union[Unset, None, MessagesConversationOrder] = MessagesConversationOrder.DESC,
) -> Response[
    Union[
        MessagesConversationResponse200,
        MessagesConversationResponse400,
        MessagesConversationResponse401,
        MessagesConversationResponse404,
        MessagesConversationResponse500,
    ]
]:

    kwargs = _get_kwargs(
        project_id=project_id,
        session_id=session_id,
        client=client,
        page=page,
        order=order,
    )

    response = requests.request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


async def asyncio(
    project_id: int,
    session_id: str,
    *,
    client: {},
    page: Union[Unset, None, int] = 1,
    order: Union[Unset, None, MessagesConversationOrder] = MessagesConversationOrder.DESC,
) -> Optional[
    Union[
        MessagesConversationResponse200,
        MessagesConversationResponse400,
        MessagesConversationResponse401,
        MessagesConversationResponse404,
        MessagesConversationResponse500,
    ]
]:
    """Retrieve messages that have been sent in a conversation.

     Retrieve all messages sent within a conversation of a project identified by its unique projectId and
    sessionId. This endpoint allows you to retrieve a collection of messages exchanged in a specific
    conversation. Messages contain the content, timestamps, and other relevant information shared during
    the course of the conversation. By providing the projectId and sessionId, you can access all the
    messages associated with that particular conversation within the project context.
    Here is an example to retrieve messages of a conversation: [API](https://github.com/Poll-The-
    People/customgpt-cookbook/blob/main/examples/Retrieve_messages_for_a_conversation.ipynb)
    [SDK](https://github.com/Poll-The-People/customgpt-
    cookbook/blob/main/examples/SDK_Retrieve_Messages_of_conversation.ipynb).

    Args:
        project_id (int):  Example: 1.
        session_id (str):  Example: 1.
        page (Union[Unset, None, int]):  Default: 1.
        order (Union[Unset, None, MessagesConversationOrder]):  Default:
            MessagesConversationOrder.DESC. Example: desc.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[MessagesConversationResponse200, MessagesConversationResponse400, MessagesConversationResponse401, MessagesConversationResponse404, MessagesConversationResponse500]
    """

    return (
        await asyncio_detailed(
            project_id=project_id,
            session_id=session_id,
            client=client,
            page=page,
            order=order,
        )
    ).parsed



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="TrafficReportsResponse200DataSourcesItem")


@attr.s(auto_attribs=True)
class TrafficReportsResponse200DataSourcesItem:
    """
    Attributes:
        request_source (Union[Unset, TrafficReportsResponse200DataSourcesItemRequestSource]):  Example: web.
        request_source_number (Union[Unset, int]):  Example: 20.
    """

    request_source: Union[Unset, str] = UNSET
    request_source_number: Union[Unset, int] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        request_source: Union[Unset, str] = UNSET
        if not isinstance(self.request_source, Unset):
            request_source = self.request_source

        request_source_number = self.request_source_number

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if request_source is not UNSET:
            field_dict["request_source"] = request_source
        if request_source_number is not UNSET:
            field_dict["request_source_number"] = request_source_number

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        request_source = src_dict.get("request_source")

        request_source_number = src_dict.get("request_source_number")

        traffic_reports_response_200_data_sources_item = cls(
            request_source=request_source,
            request_source_number=request_source_number,
        )

        traffic_reports_response_200_data_sources_item.additional_properties = src_dict
        return traffic_reports_response_200_data_sources_item

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class UpdateProjectSettingsResponse400DataMessage(str, Enum):
    LANGUAGE_PROFICIENCY_IS_REQUIRED = "Language Proficiency is required."
    PLEASE_UPLOAD_A_VALID_IMAGE_FILE_FOR_AVATAR = "Please upload a valid image file for avatar"
    PLEASE_UPLOAD_A_VALID_IMAGE_FILE_FOR_BACKGROUND = "Please upload a valid image file for background"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class UpdatePluginResponse404DataMessage(str, Enum):
    PLUGIN_FOR_PROJECT_WITH_ID_PROJECTID_NOT_FOUND = "Plugin for project with id {projectId} not found"
    PROJECT_PLUGIN_ID_IS_REQUIRED = "Project plugin id is required"
    PROJECT_PLUGIN_WITH_ID_PLUGINID_NOT_FOUND = "Project plugin with id {pluginId} not found"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="SendMessageResponse200DataMetadata")


@attr.s(auto_attribs=True)
class SendMessageResponse200DataMetadata:
    """
    Example:
        {'user_ip': '127.0.0.1', 'user_agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36
            (KHTML, like Gecko)', 'external_id': 'ext_id_1234567890', 'request_source': 'web'}

    Attributes:
        user_ip (Union[Unset, str]): The IP address of the user. Example: 127.0.0.1.
        user_agent (Union[Unset, str]): The user agent of the user. Example: Mozilla/5.0 (Macintosh; Intel Mac OS X
            10_15_7) AppleWebKit/537.36 (KHTML, like Gecko).
        external_id (Union[Unset, str]): The external ID of the prompt history. Example: ext_id_1234567890.
        request_source (Union[Unset, str]): The source of the request. Example: web.
    """

    user_ip: Union[Unset, str] = UNSET
    user_agent: Union[Unset, str] = UNSET
    external_id: Union[Unset, str] = UNSET
    request_source: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        user_ip = self.user_ip
        user_agent = self.user_agent
        external_id = self.external_id
        request_source = self.request_source

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if user_ip is not UNSET:
            field_dict["user_ip"] = user_ip
        if user_agent is not UNSET:
            field_dict["user_agent"] = user_agent
        if external_id is not UNSET:
            field_dict["external_id"] = external_id
        if request_source is not UNSET:
            field_dict["request_source"] = request_source

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        user_ip = src_dict.get("user_ip")

        user_agent = src_dict.get("user_agent")

        external_id = src_dict.get("external_id")

        request_source = src_dict.get("request_source")

        send_message_response_200_data_metadata = cls(
            user_ip=user_ip,
            user_agent=user_agent,
            external_id=external_id,
            request_source=request_source,
        )

        send_message_response_200_data_metadata.additional_properties = src_dict
        return send_message_response_200_data_metadata

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class QueriesReportsResponse200DataQueryStatusItemStatus(str, Enum):
    FAILED = "failed"
    SUCCESS = "success"

    def __str__(self) -> str:
        return str(self.value)



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.messages_conversation_response_200_data_conversation import (
        MessagesConversationResponse200DataConversation,
    )
    from ..models.messages_conversation_response_200_data_messages import MessagesConversationResponse200DataMessages


T = TypeVar("T", bound="MessagesConversationResponse200Data")


@attr.s(auto_attribs=True)
class MessagesConversationResponse200Data:
    """
    Attributes:
        conversation (Union[Unset, MessagesConversationResponse200DataConversation]):
        messages (Union[Unset, MessagesConversationResponse200DataMessages]):
    """

    conversation: Union[Unset, "MessagesConversationResponse200DataConversation"] = UNSET
    messages: Union[Unset, "MessagesConversationResponse200DataMessages"] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        conversation: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.conversation, Unset):
            conversation = self.conversation.to_dict()

        messages: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.messages, Unset):
            messages = self.messages.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if conversation is not UNSET:
            field_dict["conversation"] = conversation
        if messages is not UNSET:
            field_dict["messages"] = messages

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.messages_conversation_response_200_data_conversation import (
            MessagesConversationResponse200DataConversation,
        )
        from ..models.messages_conversation_response_200_data_messages import (
            MessagesConversationResponse200DataMessages,
        )

        _conversation = src_dict.get("conversation")
        conversation: Union[Unset, MessagesConversationResponse200DataConversation]
        if isinstance(_conversation, Unset):
            conversation = UNSET
        else:
            conversation = MessagesConversationResponse200DataConversation.from_dict(_conversation)

        _messages = src_dict.get("messages")
        messages: Union[Unset, MessagesConversationResponse200DataMessages]
        if isinstance(_messages, Unset):
            messages = UNSET
        else:
            messages = MessagesConversationResponse200DataMessages.from_dict(_messages)

        messages_conversation_response_200_data = cls(
            conversation=conversation,
            messages=messages,
        )

        messages_conversation_response_200_data.additional_properties = src_dict
        return messages_conversation_response_200_data

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="CreatePluginJsonBody")


@attr.s(auto_attribs=True)
class CreatePluginJsonBody:
    """
    Attributes:
        model_name (Union[Unset, str]): Model Name Example: IndoorPlants.
        human_name (Union[Unset, str]): Name For Human Example: The Indoor Plants Channel.
        keywords (Union[Unset, str]): Keywords For Model Example: Indoor plants, Gardening, Trusted information..
        description (Union[Unset, str]): Description For Human Example: Trusted information about indoor plants and
            gardening..
        is_active (Union[Unset, bool]): Whether the project plugin is active or not Example: True.
    """

    model_name: Union[Unset, str] = UNSET
    human_name: Union[Unset, str] = UNSET
    keywords: Union[Unset, str] = UNSET
    description: Union[Unset, str] = UNSET
    is_active: Union[Unset, bool] = False
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        model_name = self.model_name
        human_name = self.human_name
        keywords = self.keywords
        description = self.description
        is_active = True if self.is_active else False

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if model_name is not UNSET:
            field_dict["model_name"] = model_name
        if human_name is not UNSET:
            field_dict["human_name"] = human_name
        if keywords is not UNSET:
            field_dict["keywords"] = keywords
        if description is not UNSET:
            field_dict["description"] = description
        if is_active is not UNSET:
            field_dict["is_active"] = is_active

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        model_name = src_dict.get("model_name")

        human_name = src_dict.get("human_name")

        keywords = src_dict.get("keywords")

        description = src_dict.get("description")

        is_active = src_dict.get("is_active")

        create_plugin_json_body = cls(
            model_name=model_name,
            human_name=human_name,
            keywords=keywords,
            description=description,
            is_active=is_active,
        )

        create_plugin_json_body.additional_properties = src_dict
        return create_plugin_json_body

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import json
from http import HTTPStatus
from typing import Any, Dict, List, Optional, Union

import requests

from ... import errors
from ...models.analysis_reports_filters_item import AnalysisReportsFiltersItem
from ...models.analysis_reports_interval import AnalysisReportsInterval
from ...models.analysis_reports_response_200 import AnalysisReportsResponse200
from ...models.analysis_reports_response_400 import AnalysisReportsResponse400
from ...models.analysis_reports_response_401 import AnalysisReportsResponse401
from ...models.analysis_reports_response_404 import AnalysisReportsResponse404
from ...models.analysis_reports_response_500 import AnalysisReportsResponse500
from ...types import UNSET, Response, Unset


def _get_kwargs(
    project_id: int,
    *,
    client: {},
    filters: List[AnalysisReportsFiltersItem],
    interval: Union[Unset, None, AnalysisReportsInterval] = AnalysisReportsInterval.WEEKLY,
) -> Dict[str, Any]:
    url = "{}/api/v1/projects/{projectId}/reports/analysis".format(client.base_url, projectId=project_id)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {}
    json_filters = []
    for filters_item_data in filters:
        filters_item = filters_item_data

        json_filters.append(filters_item)

    params["filters"] = json_filters

    json_interval: Union[Unset, None, str] = UNSET
    if not isinstance(interval, Unset):
        json_interval = interval if interval else None

    params["interval"] = json_interval

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "method": "get",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "allow_redirects": client.follow_redirects,
        "params": params,
    }


def _parse_response(*, client: {}, response: None) -> Optional[
    Union[
        AnalysisReportsResponse200,
        AnalysisReportsResponse400,
        AnalysisReportsResponse401,
        AnalysisReportsResponse404,
        AnalysisReportsResponse500,
    ]
]:
    if response.status_code == HTTPStatus.OK:
        response_200 = AnalysisReportsResponse200.from_dict(json.loads(response.text))

        return response_200
    if response.status_code == HTTPStatus.BAD_REQUEST:
        response_400 = AnalysisReportsResponse400.from_dict(json.loads(response.text))

        return response_400
    if response.status_code == HTTPStatus.UNAUTHORIZED:
        response_401 = AnalysisReportsResponse401.from_dict(json.loads(response.text))

        return response_401
    if response.status_code == HTTPStatus.NOT_FOUND:
        response_404 = AnalysisReportsResponse404.from_dict(json.loads(response.text))

        return response_404
    if response.status_code == HTTPStatus.INTERNAL_SERVER_ERROR:
        response_500 = AnalysisReportsResponse500.from_dict(json.loads(response.text))

        return response_500
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(*, client: {}, response: None, content: Optional[bytes] = None) -> Response[
    Union[
        AnalysisReportsResponse200,
        AnalysisReportsResponse400,
        AnalysisReportsResponse401,
        AnalysisReportsResponse404,
        AnalysisReportsResponse500,
    ]
]:
    parse = _parse_response(client=client, response=response)
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content if content is None else content,
        headers=response.headers,
        parsed=parse,
    )


def sync_detailed(
    project_id: int,
    *,
    client: {},
    filters: List[AnalysisReportsFiltersItem],
    interval: Union[Unset, None, AnalysisReportsInterval] = AnalysisReportsInterval.WEEKLY,
):
    """Provide graph-ready analysis data of various metrics.

    Args:
        project_id (int):  Example: 1.
        filters (List[AnalysisReportsFiltersItem]):
        interval (Union[Unset, None, AnalysisReportsInterval]):  Default:
            AnalysisReportsInterval.WEEKLY.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[AnalysisReportsResponse200, AnalysisReportsResponse400, AnalysisReportsResponse401, AnalysisReportsResponse404, AnalysisReportsResponse500]]
    """

    kwargs = _get_kwargs(
        project_id=project_id,
        client=client,
        filters=filters,
        interval=interval,
    )

    response = requests.request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    project_id: int,
    *,
    client: {},
    filters: List[AnalysisReportsFiltersItem],
    interval: Union[Unset, None, AnalysisReportsInterval] = AnalysisReportsInterval.WEEKLY,
) -> Optional[
    Union[
        AnalysisReportsResponse200,
        AnalysisReportsResponse400,
        AnalysisReportsResponse401,
        AnalysisReportsResponse404,
        AnalysisReportsResponse500,
    ]
]:
    """Provide graph-ready analysis data of various metrics.

    Args:
        project_id (int):  Example: 1.
        filters (List[AnalysisReportsFiltersItem]):
        interval (Union[Unset, None, AnalysisReportsInterval]):  Default:
            AnalysisReportsInterval.WEEKLY.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[AnalysisReportsResponse200, AnalysisReportsResponse400, AnalysisReportsResponse401, AnalysisReportsResponse404, AnalysisReportsResponse500]
    """

    return sync_detailed(
        project_id=project_id,
        client=client,
        filters=filters,
        interval=interval,
    ).parsed


async def asyncio_detailed(
    project_id: int,
    *,
    client: {},
    filters: List[AnalysisReportsFiltersItem],
    interval: Union[Unset, None, AnalysisReportsInterval] = AnalysisReportsInterval.WEEKLY,
) -> Response[
    Union[
        AnalysisReportsResponse200,
        AnalysisReportsResponse400,
        AnalysisReportsResponse401,
        AnalysisReportsResponse404,
        AnalysisReportsResponse500,
    ]
]:

    kwargs = _get_kwargs(
        project_id=project_id,
        client=client,
        filters=filters,
        interval=interval,
    )

    response = requests.request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


async def asyncio(
    project_id: int,
    *,
    client: {},
    filters: List[AnalysisReportsFiltersItem],
    interval: Union[Unset, None, AnalysisReportsInterval] = AnalysisReportsInterval.WEEKLY,
) -> Optional[
    Union[
        AnalysisReportsResponse200,
        AnalysisReportsResponse400,
        AnalysisReportsResponse401,
        AnalysisReportsResponse404,
        AnalysisReportsResponse500,
    ]
]:
    """Provide graph-ready analysis data of various metrics.

    Args:
        project_id (int):  Example: 1.
        filters (List[AnalysisReportsFiltersItem]):
        interval (Union[Unset, None, AnalysisReportsInterval]):  Default:
            AnalysisReportsInterval.WEEKLY.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[AnalysisReportsResponse200, AnalysisReportsResponse400, AnalysisReportsResponse401, AnalysisReportsResponse404, AnalysisReportsResponse500]
    """

    return (
        await asyncio_detailed(
            project_id=project_id,
            client=client,
            filters=filters,
            interval=interval,
        )
    ).parsed



import json
from http import HTTPStatus
from typing import Any, Dict, Optional, Union

import requests

from ... import errors
from ...models.get_pages_order import GetPagesOrder
from ...models.get_pages_response_200 import GetPagesResponse200
from ...models.get_pages_response_400 import GetPagesResponse400
from ...models.get_pages_response_401 import GetPagesResponse401
from ...models.get_pages_response_404 import GetPagesResponse404
from ...models.get_pages_response_500 import GetPagesResponse500
from ...types import UNSET, Response, Unset


def _get_kwargs(
    project_id: int,
    *,
    client: {},
    page: Union[Unset, None, int] = 1,
    duration: Union[Unset, None, int] = 90,
    order: Union[Unset, None, GetPagesOrder] = GetPagesOrder.DESC,
) -> Dict[str, Any]:
    url = "{}/api/v1/projects/{projectId}/pages".format(client.base_url, projectId=project_id)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {}
    params["page"] = page

    params["duration"] = duration

    json_order: Union[Unset, None, str] = UNSET
    if not isinstance(order, Unset):
        json_order = order if order else None

    params["order"] = json_order

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "method": "get",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "allow_redirects": client.follow_redirects,
        "params": params,
    }


def _parse_response(
    *, client: {}, response: None
) -> Optional[
    Union[GetPagesResponse200, GetPagesResponse400, GetPagesResponse401, GetPagesResponse404, GetPagesResponse500]
]:
    if response.status_code == HTTPStatus.OK:
        response_200 = GetPagesResponse200.from_dict(json.loads(response.text))

        return response_200
    if response.status_code == HTTPStatus.BAD_REQUEST:
        response_400 = GetPagesResponse400.from_dict(json.loads(response.text))

        return response_400
    if response.status_code == HTTPStatus.UNAUTHORIZED:
        response_401 = GetPagesResponse401.from_dict(json.loads(response.text))

        return response_401
    if response.status_code == HTTPStatus.NOT_FOUND:
        response_404 = GetPagesResponse404.from_dict(json.loads(response.text))

        return response_404
    if response.status_code == HTTPStatus.INTERNAL_SERVER_ERROR:
        response_500 = GetPagesResponse500.from_dict(json.loads(response.text))

        return response_500
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: {}, response: None, content: Optional[bytes] = None
) -> Response[
    Union[GetPagesResponse200, GetPagesResponse400, GetPagesResponse401, GetPagesResponse404, GetPagesResponse500]
]:
    parse = _parse_response(client=client, response=response)
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content if content is None else content,
        headers=response.headers,
        parsed=parse,
    )


def sync_detailed(
    project_id: int,
    *,
    client: {},
    page: Union[Unset, None, int] = 1,
    duration: Union[Unset, None, int] = 90,
    order: Union[Unset, None, GetPagesOrder] = GetPagesOrder.DESC,
):
    """List all pages that belong to a project.

     Retrieve a list of all pages associated with a project. This endpoint allows you to fetch project
    details and a collection of pages that belong to a specific project. Each page object includes
    information such as the page ID, URL, hash of the URL, project ID, crawl status, index status, file
    details (if applicable), creation and update timestamps, and other relevant attributes.
    Here is an example to list all pages belonging to project: [API](https://github.com/Poll-The-
    People/customgpt-cookbook/blob/main/examples/List_all_pages_of_a_project.ipynb)
    [SDK](https://github.com/Poll-The-People/customgpt-
    cookbook/blob/main/examples/SDK_List_all_pages_belonging_to_a_project.ipynb).

    Args:
        project_id (int):  Example: 1.
        page (Union[Unset, None, int]):  Default: 1.
        duration (Union[Unset, None, int]):  Default: 90.
        order (Union[Unset, None, GetPagesOrder]):  Default: GetPagesOrder.DESC.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[GetPagesResponse200, GetPagesResponse400, GetPagesResponse401, GetPagesResponse404, GetPagesResponse500]]
    """

    kwargs = _get_kwargs(
        project_id=project_id,
        client=client,
        page=page,
        duration=duration,
        order=order,
    )

    response = requests.request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    project_id: int,
    *,
    client: {},
    page: Union[Unset, None, int] = 1,
    duration: Union[Unset, None, int] = 90,
    order: Union[Unset, None, GetPagesOrder] = GetPagesOrder.DESC,
) -> Optional[
    Union[GetPagesResponse200, GetPagesResponse400, GetPagesResponse401, GetPagesResponse404, GetPagesResponse500]
]:
    """List all pages that belong to a project.

     Retrieve a list of all pages associated with a project. This endpoint allows you to fetch project
    details and a collection of pages that belong to a specific project. Each page object includes
    information such as the page ID, URL, hash of the URL, project ID, crawl status, index status, file
    details (if applicable), creation and update timestamps, and other relevant attributes.
    Here is an example to list all pages belonging to project: [API](https://github.com/Poll-The-
    People/customgpt-cookbook/blob/main/examples/List_all_pages_of_a_project.ipynb)
    [SDK](https://github.com/Poll-The-People/customgpt-
    cookbook/blob/main/examples/SDK_List_all_pages_belonging_to_a_project.ipynb).

    Args:
        project_id (int):  Example: 1.
        page (Union[Unset, None, int]):  Default: 1.
        duration (Union[Unset, None, int]):  Default: 90.
        order (Union[Unset, None, GetPagesOrder]):  Default: GetPagesOrder.DESC.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[GetPagesResponse200, GetPagesResponse400, GetPagesResponse401, GetPagesResponse404, GetPagesResponse500]
    """

    return sync_detailed(
        project_id=project_id,
        client=client,
        page=page,
        duration=duration,
        order=order,
    ).parsed


async def asyncio_detailed(
    project_id: int,
    *,
    client: {},
    page: Union[Unset, None, int] = 1,
    duration: Union[Unset, None, int] = 90,
    order: Union[Unset, None, GetPagesOrder] = GetPagesOrder.DESC,
) -> Response[
    Union[GetPagesResponse200, GetPagesResponse400, GetPagesResponse401, GetPagesResponse404, GetPagesResponse500]
]:

    kwargs = _get_kwargs(
        project_id=project_id,
        client=client,
        page=page,
        duration=duration,
        order=order,
    )

    response = requests.request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


async def asyncio(
    project_id: int,
    *,
    client: {},
    page: Union[Unset, None, int] = 1,
    duration: Union[Unset, None, int] = 90,
    order: Union[Unset, None, GetPagesOrder] = GetPagesOrder.DESC,
) -> Optional[
    Union[GetPagesResponse200, GetPagesResponse400, GetPagesResponse401, GetPagesResponse404, GetPagesResponse500]
]:
    """List all pages that belong to a project.

     Retrieve a list of all pages associated with a project. This endpoint allows you to fetch project
    details and a collection of pages that belong to a specific project. Each page object includes
    information such as the page ID, URL, hash of the URL, project ID, crawl status, index status, file
    details (if applicable), creation and update timestamps, and other relevant attributes.
    Here is an example to list all pages belonging to project: [API](https://github.com/Poll-The-
    People/customgpt-cookbook/blob/main/examples/List_all_pages_of_a_project.ipynb)
    [SDK](https://github.com/Poll-The-People/customgpt-
    cookbook/blob/main/examples/SDK_List_all_pages_belonging_to_a_project.ipynb).

    Args:
        project_id (int):  Example: 1.
        page (Union[Unset, None, int]):  Default: 1.
        duration (Union[Unset, None, int]):  Default: 90.
        order (Union[Unset, None, GetPagesOrder]):  Default: GetPagesOrder.DESC.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[GetPagesResponse200, GetPagesResponse400, GetPagesResponse401, GetPagesResponse404, GetPagesResponse500]
    """

    return (
        await asyncio_detailed(
            project_id=project_id,
            client=client,
            page=page,
            duration=duration,
            order=order,
        )
    ).parsed



from enum import Enum


class UpdateConversationResponse404DataMessage(str, Enum):
    PROJECT_ID_IS_REQUIRED = "Project id is required"
    PROJECT_WITH_ID_PROJECTID_NOT_FOUND = "Project with id {projectId} not found"

    def __str__(self) -> str:
        return str(self.value)



from io import BytesIO
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, File, FileJsonType, Unset

T = TypeVar("T", bound="CreateSourceMultipartData")


@attr.s(auto_attribs=True)
class CreateSourceMultipartData:
    """
    Attributes:
        sitemap_path (Union[Unset, str]): The sitemap path Example: https://example.com/sitemap.xml.
        file_data_retension (Union[Unset, bool]): File data retension Example: True.
        is_ocr_enabled (Union[Unset, bool]): OCR enabled
        is_anonymized (Union[Unset, bool]): Anonymized
        file (Union[Unset, File]): The submitted file. Example: file.pdf.
    """

    sitemap_path: Union[Unset, str] = UNSET
    file_data_retension: Union[Unset, bool] = UNSET
    is_ocr_enabled: Union[Unset, bool] = UNSET
    is_anonymized: Union[Unset, bool] = UNSET
    file: Union[Unset, File] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        sitemap_path = self.sitemap_path
        file_data_retension = True if self.file_data_retension else False

        is_ocr_enabled = True if self.is_ocr_enabled else False

        is_anonymized = True if self.is_anonymized else False

        file: Union[Unset, FileJsonType] = UNSET
        if not isinstance(self.file, Unset):
            file = self.file.to_tuple()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if sitemap_path is not UNSET:
            field_dict["sitemap_path"] = sitemap_path
        if file_data_retension is not UNSET:
            field_dict["file_data_retension"] = file_data_retension
        if is_ocr_enabled is not UNSET:
            field_dict["is_ocr_enabled"] = is_ocr_enabled
        if is_anonymized is not UNSET:
            field_dict["is_anonymized"] = is_anonymized
        if file is not UNSET:
            field_dict["file"] = file

        return field_dict

    def to_multipart(self) -> Dict[str, Any]:
        sitemap_path = (
            self.sitemap_path
            if isinstance(self.sitemap_path, Unset)
            else (None, str(self.sitemap_path).encode(), "text/plain")
        )
        file_data_retension = (
            self.file_data_retension
            if isinstance(self.file_data_retension, Unset)
            else (None, str(self.file_data_retension).lower().encode(), "text/plain")
        )

        is_ocr_enabled = (
            self.is_ocr_enabled
            if isinstance(self.is_ocr_enabled, Unset)
            else (None, str(self.is_ocr_enabled).lower().encode(), "text/plain")
        )

        is_anonymized = (
            self.is_anonymized
            if isinstance(self.is_anonymized, Unset)
            else (None, str(self.is_anonymized).lower().encode(), "text/plain")
        )

        file: Union[Unset, FileJsonType] = UNSET
        if not isinstance(self.file, Unset):
            file = self.file.to_tuple()

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {key: (None, str(value).encode(), "text/plain") for key, value in self.additional_properties.items()}
        )
        field_dict.update({})
        if sitemap_path is not UNSET:
            field_dict["sitemap_path"] = sitemap_path
        if file_data_retension is not UNSET:
            field_dict["file_data_retension"] = file_data_retension
        if is_ocr_enabled is not UNSET:
            field_dict["is_ocr_enabled"] = is_ocr_enabled
        if is_anonymized is not UNSET:
            field_dict["is_anonymized"] = is_anonymized
        if file is not UNSET:
            field_dict["file"] = file

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        sitemap_path = src_dict.get("sitemap_path")

        file_data_retension = src_dict.get("file_data_retension")

        is_ocr_enabled = src_dict.get("is_ocr_enabled")

        is_anonymized = src_dict.get("is_anonymized")

        _file = src_dict.get("file")
        file: Union[Unset, File]
        if isinstance(_file, Unset):
            file = UNSET
        else:
            file = File(payload=BytesIO(_file))

        create_source_multipart_data = cls(
            sitemap_path=sitemap_path,
            file_data_retension=file_data_retension,
            is_ocr_enabled=is_ocr_enabled,
            is_anonymized=is_anonymized,
            file=file,
        )

        create_source_multipart_data.additional_properties = src_dict
        return create_source_multipart_data

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="ConversationsReportsResponse200Data")


@attr.s(auto_attribs=True)
class ConversationsReportsResponse200Data:
    """
    Attributes:
        total (Union[Unset, int]): Total number of conversations Example: 10.
        average_queries_per_conversation (Union[Unset, int]): Average number of queries per conversations Example: 1.2.
    """

    total: Union[Unset, int] = UNSET
    average_queries_per_conversation: Union[Unset, int] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        total = self.total
        average_queries_per_conversation = self.average_queries_per_conversation

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if total is not UNSET:
            field_dict["total"] = total
        if average_queries_per_conversation is not UNSET:
            field_dict["average_queries_per_conversation"] = average_queries_per_conversation

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        total = src_dict.get("total")

        average_queries_per_conversation = src_dict.get("average_queries_per_conversation")

        conversations_reports_response_200_data = cls(
            total=total,
            average_queries_per_conversation=average_queries_per_conversation,
        )

        conversations_reports_response_200_data.additional_properties = src_dict
        return conversations_reports_response_200_data

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.create_source_response_201_data_pages_item import CreateSourceResponse201DataPagesItem
    from ..models.create_source_response_201_data_settings import CreateSourceResponse201DataSettings


T = TypeVar("T", bound="CreateSourceResponse201Data")


@attr.s(auto_attribs=True)
class CreateSourceResponse201Data:
    """
    Attributes:
        id (Union[Unset, int]): The project source ID Example: 1.
        created_at (Union[Unset, datetime.datetime]): The project source creation date Example: 2021-01-01 00:00:00.
        updated_at (Union[Unset, datetime.datetime]): The project source update date Example: 2021-01-01 00:00:00.
        type (Union[Unset, CreateSourceResponse201DataType]): The project source type Example: sitemap.
        settings (Union[Unset, CreateSourceResponse201DataSettings]): The project source settings
        pages (Union[Unset, None, List['CreateSourceResponse201DataPagesItem']]): The project source pages
    """

    id: Union[Unset, int] = UNSET
    created_at: Union[Unset, datetime.datetime] = UNSET
    updated_at: Union[Unset, datetime.datetime] = UNSET
    type: Union[Unset, str] = UNSET
    settings: Union[Unset, "CreateSourceResponse201DataSettings"] = UNSET
    pages: Union[Unset, None, List["CreateSourceResponse201DataPagesItem"]] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        id = self.id
        created_at: Union[Unset, str] = UNSET
        if not isinstance(self.created_at, Unset):
            created_at = self.created_at.isoformat()

        updated_at: Union[Unset, str] = UNSET
        if not isinstance(self.updated_at, Unset):
            updated_at = self.updated_at.isoformat()

        type: Union[Unset, str] = UNSET
        if not isinstance(self.type, Unset):
            type = self.type

        settings: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.settings, Unset):
            settings = self.settings.to_dict()

        pages: Union[Unset, None, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.pages, Unset):
            if self.pages is None:
                pages = None
            else:
                pages = []
                for pages_item_data in self.pages:
                    pages_item = pages_item_data.to_dict()

                    pages.append(pages_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if id is not UNSET:
            field_dict["id"] = id
        if created_at is not UNSET:
            field_dict["created_at"] = created_at
        if updated_at is not UNSET:
            field_dict["updated_at"] = updated_at
        if type is not UNSET:
            field_dict["type"] = type
        if settings is not UNSET:
            field_dict["settings"] = settings
        if pages is not UNSET:
            for index, field_value in enumerate(pages):
                field_dict[f"pages[{index}]"] = field_value

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.create_source_response_201_data_pages_item import CreateSourceResponse201DataPagesItem
        from ..models.create_source_response_201_data_settings import CreateSourceResponse201DataSettings

        id = src_dict.get("id")

        _created_at = src_dict.get("created_at")
        created_at: Union[Unset, datetime.datetime]
        if isinstance(_created_at, Unset):
            created_at = UNSET
        else:
            created_at = isoparse(_created_at)

        _updated_at = src_dict.get("updated_at")
        updated_at: Union[Unset, datetime.datetime]
        if isinstance(_updated_at, Unset):
            updated_at = UNSET
        else:
            updated_at = isoparse(_updated_at)

        type = src_dict.get("type")

        _settings = src_dict.get("settings")
        settings: Union[Unset, CreateSourceResponse201DataSettings]
        if isinstance(_settings, Unset):
            settings = UNSET
        else:
            settings = CreateSourceResponse201DataSettings.from_dict(_settings)

        pages = []
        _pages = src_dict.get("pages")
        for pages_item_data in _pages or []:
            pages_item = CreateSourceResponse201DataPagesItem.from_dict(pages_item_data)

            pages.append(pages_item)

        create_source_response_201_data = cls(
            id=id,
            created_at=created_at,
            updated_at=updated_at,
            type=type,
            settings=settings,
            pages=pages,
        )

        create_source_response_201_data.additional_properties = src_dict
        return create_source_response_201_data

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="ProjectAnalyticsAnalysisQueriesPerConversationItem")


@attr.s(auto_attribs=True)
class ProjectAnalyticsAnalysisQueriesPerConversationItem:
    """
    Attributes:
        queries_number (Union[Unset, int]):  Example: 1.5.
        created_at_interval (Union[Unset, str]):  Example: Sat.
    """

    queries_number: Union[Unset, int] = UNSET
    created_at_interval: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        queries_number = self.queries_number
        created_at_interval = self.created_at_interval

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if queries_number is not UNSET:
            field_dict["queries_number"] = queries_number
        if created_at_interval is not UNSET:
            field_dict["created_at_interval"] = created_at_interval

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        queries_number = src_dict.get("queries_number")

        created_at_interval = src_dict.get("created_at_interval")

        project_analytics_analysis_queries_per_conversation_item = cls(
            queries_number=queries_number,
            created_at_interval=created_at_interval,
        )

        project_analytics_analysis_queries_per_conversation_item.additional_properties = src_dict
        return project_analytics_analysis_queries_per_conversation_item

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class ReindexPageResponse403DataMessage(str, Enum):
    PAGE_WITH_ID_PAGEID_CANNOT_BE_REINDEXED = "Page with id {pageId} cannot be reindexed"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="SendMessageJsonBody")


@attr.s(auto_attribs=True)
class SendMessageJsonBody:
    """
    Attributes:
        prompt (Union[Unset, str]): Prompt to send to OpenAI Example: Write me hello world program in C.
        custom_persona (Union[Unset, None, str]): Custom persona to use for the conversation Example: You are a custom
            chatbot assistant called *bot name*, a friendly *bot role* who works for *organization* and answers questions
            based on the given context. Be as helpful as possible. Always prioritize the customer. Escalate complex issues.
            Stay on topic. Use appropriate language, Acknowledge limitations..
        chatbot_model (Union[Unset, None, SendMessageJsonBodyChatbotModel]): Chatbot model to use for the conversation
            Example: gpt-4.
        response_source (Union[Unset, None, SendMessageJsonBodyResponseSource]): By default, we ask ChatGPT to use only
            your content in its response (recommended). If you wish ChatGPT to improvise and use its own knowledgebase as
            well, you can set this to "openai_content". Default: SendMessageJsonBodyResponseSource.DEFAULT. Example:
            default.
    """

    prompt: Union[Unset, str] = UNSET
    custom_persona: Union[Unset, None, str] = UNSET
    chatbot_model: Union[Unset, str] = UNSET
    response_source: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        prompt = self.prompt
        custom_persona = self.custom_persona
        chatbot_model: Union[Unset, None, str] = UNSET
        if not isinstance(self.chatbot_model, Unset):
            chatbot_model = self.chatbot_model if self.chatbot_model else None

        response_source: Union[Unset, None, str] = UNSET
        if not isinstance(self.response_source, Unset):
            response_source = self.response_source if self.response_source else None

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if prompt is not UNSET:
            field_dict["prompt"] = prompt
        if custom_persona is not UNSET:
            field_dict["custom_persona"] = custom_persona
        if chatbot_model is not UNSET:
            field_dict["chatbot_model"] = chatbot_model
        if response_source is not UNSET:
            field_dict["response_source"] = response_source

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        prompt = src_dict.get("prompt")

        custom_persona = src_dict.get("custom_persona")

        chatbot_model = src_dict.get("chatbot_model")

        response_source = src_dict.get("response_source")

        send_message_json_body = cls(
            prompt=prompt,
            custom_persona=custom_persona,
            chatbot_model=chatbot_model,
            response_source=response_source,
        )

        send_message_json_body.additional_properties = src_dict
        return send_message_json_body

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.list_sources_response_200_data_sitemaps_item import ListSourcesResponse200DataSitemapsItem
    from ..models.list_sources_response_200_data_uploads import ListSourcesResponse200DataUploads


T = TypeVar("T", bound="ListSourcesResponse200Data")


@attr.s(auto_attribs=True)
class ListSourcesResponse200Data:
    """
    Attributes:
        sitemaps (Union[Unset, List['ListSourcesResponse200DataSitemapsItem']]):
        uploads (Union[Unset, ListSourcesResponse200DataUploads]):
    """

    sitemaps: Union[Unset, List["ListSourcesResponse200DataSitemapsItem"]] = UNSET
    uploads: Union[Unset, "ListSourcesResponse200DataUploads"] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        sitemaps: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.sitemaps, Unset):
            sitemaps = []
            for sitemaps_item_data in self.sitemaps:
                sitemaps_item = sitemaps_item_data.to_dict()

                sitemaps.append(sitemaps_item)

        uploads: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.uploads, Unset):
            uploads = self.uploads.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if sitemaps is not UNSET:
            for index, field_value in enumerate(sitemaps):
                field_dict[f"sitemaps[{index}]"] = field_value
        if uploads is not UNSET:
            field_dict["uploads"] = uploads

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.list_sources_response_200_data_sitemaps_item import ListSourcesResponse200DataSitemapsItem
        from ..models.list_sources_response_200_data_uploads import ListSourcesResponse200DataUploads

        sitemaps = []
        _sitemaps = src_dict.get("sitemaps")
        for sitemaps_item_data in _sitemaps or []:
            sitemaps_item = ListSourcesResponse200DataSitemapsItem.from_dict(sitemaps_item_data)

            sitemaps.append(sitemaps_item)

        _uploads = src_dict.get("uploads")
        uploads: Union[Unset, ListSourcesResponse200DataUploads]
        if isinstance(_uploads, Unset):
            uploads = UNSET
        else:
            uploads = ListSourcesResponse200DataUploads.from_dict(_uploads)

        list_sources_response_200_data = cls(
            sitemaps=sitemaps,
            uploads=uploads,
        )

        list_sources_response_200_data.additional_properties = src_dict
        return list_sources_response_200_data

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class AnalysisReportsFiltersItem(str, Enum):
    CONVERSATIONS = "conversations"
    QUERIES = "queries"
    QUERIES_PER_CONVERSATION = "queries_per_conversation"

    def __str__(self) -> str:
        return str(self.value)



import json
from http import HTTPStatus
from typing import Any, Dict, Optional, Union

import requests

from ... import errors
from ...models.get_user_response_200 import GetUserResponse200
from ...models.get_user_response_401 import GetUserResponse401
from ...models.get_user_response_500 import GetUserResponse500
from ...types import Response


def _get_kwargs(
    *,
    client: {},
) -> Dict[str, Any]:
    url = "{}/api/v1/user".format(client.base_url)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    return {
        "method": "get",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "allow_redirects": client.follow_redirects,
    }


def _parse_response(
    *, client: {}, response: None
) -> Optional[Union[GetUserResponse200, GetUserResponse401, GetUserResponse500]]:
    if response.status_code == HTTPStatus.OK:
        response_200 = GetUserResponse200.from_dict(json.loads(response.text))

        return response_200
    if response.status_code == HTTPStatus.UNAUTHORIZED:
        response_401 = GetUserResponse401.from_dict(json.loads(response.text))

        return response_401
    if response.status_code == HTTPStatus.INTERNAL_SERVER_ERROR:
        response_500 = GetUserResponse500.from_dict(json.loads(response.text))

        return response_500
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: {}, response: None, content: Optional[bytes] = None
) -> Response[Union[GetUserResponse200, GetUserResponse401, GetUserResponse500]]:
    parse = _parse_response(client=client, response=response)
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content if content is None else content,
        headers=response.headers,
        parsed=parse,
    )


def sync_detailed(
    *,
    client: {},
):
    """Show the user's profile.

     Retrieve the profile information of the current user. This endpoint allows you to fetch the details
    and attributes associated with the user's profile, providing valuable information about the user's
    account and preferences.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[GetUserResponse200, GetUserResponse401, GetUserResponse500]]
    """

    kwargs = _get_kwargs(
        client=client,
    )

    response = requests.request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: {},
) -> Optional[Union[GetUserResponse200, GetUserResponse401, GetUserResponse500]]:
    """Show the user's profile.

     Retrieve the profile information of the current user. This endpoint allows you to fetch the details
    and attributes associated with the user's profile, providing valuable information about the user's
    account and preferences.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[GetUserResponse200, GetUserResponse401, GetUserResponse500]
    """

    return sync_detailed(
        client=client,
    ).parsed


async def asyncio_detailed(
    *,
    client: {},
) -> Response[Union[GetUserResponse200, GetUserResponse401, GetUserResponse500]]:

    kwargs = _get_kwargs(
        client=client,
    )

    response = requests.request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: {},
) -> Optional[Union[GetUserResponse200, GetUserResponse401, GetUserResponse500]]:
    """Show the user's profile.

     Retrieve the profile information of the current user. This endpoint allows you to fetch the details
    and attributes associated with the user's profile, providing valuable information about the user's
    account and preferences.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[GetUserResponse200, GetUserResponse401, GetUserResponse500]
    """

    return (
        await asyncio_detailed(
            client=client,
        )
    ).parsed



from enum import IntEnum


class UpdateProjectSettingsMultipartDataEnableCitations(IntEnum):
    VALUE_0 = 0
    VALUE_1 = 1
    VALUE_2 = 2
    VALUE_3 = 3

    def __str__(self) -> str:
        return str(self.value)



import ssl
from typing import Any, Dict, Union

import attr

from customgpt_client.api.citations import get_citation
from customgpt_client.api.conversations import (
    create_conversation,
    delete_conversation,
    get_conversations,
    messages_conversation,
    send_message,
    update_conversation,
)
from customgpt_client.api.limits import get_api_v1_limits_usage
from customgpt_client.api.page_metadata import get_metadata, update_metadata
from customgpt_client.api.pages import delete_page, get_pages, preview_citation, reindex_page
from customgpt_client.api.project_plugins import create_plugin, get_plugin, update_plugin
from customgpt_client.api.project_settings import get_project_settings, update_project_settings
from customgpt_client.api.projects import (
    create_project,
    delete_project,
    get_project,
    list_projects,
    replicate_project,
    stats_project,
    update_project,
)
from customgpt_client.api.reports_analytics import (
    analysis_reports,
    conversations_reports,
    queries_reports,
    traffic_reports,
)
from customgpt_client.api.sources import create_source, delete_source, list_sources, synchronize_source, update_source
from customgpt_client.api.users import get_user, update_user
from customgpt_client.models import (
    CreateConversationJsonBody,
    CreatePluginJsonBody,
    CreateProjectMultipartData,
    CreateSourceMultipartData,
    SendMessageJsonBody,
    UpdateConversationJsonBody,
    UpdateMetadataJsonBody,
    UpdatePluginJsonBody,
    UpdateProjectMultipartData,
    UpdateProjectSettingsMultipartData,
    UpdateSourceJsonBody,
    UpdateUserMultipartData,
)


def set_client():
    api_key = CustomGPT.api_key if hasattr(CustomGPT, "api_key") else ""
    base_url = CustomGPT.base_url if hasattr(CustomGPT, "base_url") else "https://app.customgpt.ai"
    timeout = CustomGPT.timeout if hasattr(CustomGPT, "timeout") else 100.0
    headers = CustomGPT.headers if hasattr(CustomGPT, "headers") else {}
    return CustomGPT(api_key=api_key, base_url=base_url, timeout=timeout, headers=headers)


def pluck_data(fields, kwargs):
    json = {}
    for field in fields:
        if field in kwargs:
            json[field] = kwargs.pop(field)
    return json


@attr.s(auto_attribs=True)
class CustomGPT:
    """A Client which has been authenticated for use on secured endpoints
    Attributes:
        base_url: The base URL for the API, all requests are made to a relative path to this URL
        cookies: A dictionary of cookies to be sent with every request
        headers: A dictionary of headers to be sent with every request
        timeout: The maximum amount of a time in seconds a request can take. API functions will raise
            httpx.TimeoutException if this is exceeded.
        verify_ssl: Whether or not to verify the SSL certificate of the API server. This should be True in production,
            but can be set to False for testing purposes.
        raise_on_unexpected_status: Whether or not to raise an errors.UnexpectedStatus if the API returns a
            status code that was not documented in the source OpenAPI document.
        follow_redirects: Whether or not to follow redirects. Default value is False.
    """

    api_key: str
    prefix: str = "Bearer"
    auth_header_name: str = "Authorization"
    base_url: str = attr.ib("https://app.customgpt.ai")
    cookies: Dict[str, str] = attr.ib(factory=dict, kw_only=True)
    headers: Dict[str, str] = attr.ib(factory=dict, kw_only=True)
    timeout: float = attr.ib(5.0, kw_only=True)
    verify_ssl: Union[str, bool, ssl.SSLContext] = attr.ib(True, kw_only=True)
    raise_on_unexpected_status: bool = attr.ib(False, kw_only=True)
    follow_redirects: bool = attr.ib(False, kw_only=True)

    def with_headers(self, headers: Dict[str, str]) -> "CustomGPT":
        """Get a new client matching this one with additional headers"""
        return attr.evolve(self, headers={**self.headers, **headers})

    def get_cookies(self) -> Dict[str, str]:
        return {**self.cookies}

    def with_cookies(self, cookies: Dict[str, str]) -> "CustomGPT":
        """Get a new client matching this one with additional cookies"""
        return attr.evolve(self, cookies={**self.cookies, **cookies})

    def get_timeout(self) -> float:
        return self.timeout

    def with_timeout(self, timeout: float) -> "CustomGPT":
        """Get a new client matching this one with a new timeout (in seconds)"""
        return attr.evolve(self, timeout=timeout)

    def get_headers(self) -> Dict[str, str]:
        """Get headers to be used in authenticated endpoints"""
        auth_header_value = f"{self.prefix} {self.api_key}" if self.prefix else self.api_key
        return {self.auth_header_name: auth_header_value, **self.headers}

    class Project:
        def list(*args: Any, **kwargs: Any):
            client = set_client()

            return list_projects.sync_detailed(client=client, *args, **kwargs)

        def alist(*args: Any, **kwargs: Any):
            client = set_client()

            return list_projects.asyncio_detailed(client=client, *args, **kwargs)

        def create(*args: Any, **kwargs: Any):
            client = set_client()
            fields = ["project_name", "sitemap_path", "file_data_retension", "is_ocr_enabled", "is_anonymized", "file"]
            json = pluck_data(fields, kwargs)
            kwargs["multipart_data"] = CreateProjectMultipartData(**json)

            return create_project.sync_detailed(client=client, *args, **kwargs)

        def acreate(*args: Any, **kwargs: Any):
            client = set_client()
            fields = ["project_name", "sitemap_path", "file_data_retension", "is_ocr_enabled", "is_anonymized", "file"]
            json = pluck_data(fields, kwargs)
            kwargs["multipart_data"] = CreateProjectMultipartData(**json)

            return create_project.asyncio_detailed(client=client, *args, **kwargs)

        def get(*args: Any, **kwargs: Any):
            client = set_client()

            return get_project.sync_detailed(client=client, *args, **kwargs)

        def aget(*args: Any, **kwargs: Any):
            client = set_client()

            return get_project.asyncio_detailed(client=client, *args, **kwargs)

        def update(*args: Any, **kwargs: Any):
            client = set_client()
            fields = [
                "project_name",
                "is_shared",
                "sitemap_path",
                "file_data_retension",
                "is_ocr_enabled",
                "is_anonymized",
                "file",
            ]
            json = pluck_data(fields, kwargs)
            kwargs["multipart_data"] = UpdateProjectMultipartData(**json)

            return update_project.sync_detailed(client=client, *args, **kwargs)

        def aupdate(*args: Any, **kwargs: Any):
            client = set_client()
            fields = [
                "project_name",
                "is_shared",
                "sitemap_path",
                "file_data_retension",
                "is_ocr_enabled",
                "is_anonymized",
                "file",
            ]
            json = pluck_data(fields, kwargs)
            kwargs["multipart_data"] = UpdateProjectMultipartData(**json)

            return update_project.asyncio_detailed(client=client, *args, **kwargs)

        def delete(*args: Any, **kwargs: Any):
            client = set_client()

            return delete_project.sync_detailed(client=client, *args, **kwargs)

        def adelete(*args: Any, **kwargs: Any):
            client = set_client()

            return delete_project.asyncio_detailed(client=client, *args, **kwargs)

        def replicate(*args: Any, **kwargs: Any):
            client = set_client()

            return replicate_project.sync_detailed(client=client, *args, **kwargs)

        def areplicate(*args: Any, **kwargs: Any):
            client = set_client()

            return replicate_project.asyncio_detailed(client=client, *args, **kwargs)

        def stats(*args: Any, **kwargs: Any):
            client = set_client()

            return stats_project.sync_detailed(client=client, *args, **kwargs)

        def astats(*args: Any, **kwargs: Any):
            client = set_client()

            return stats_project.asyncio_detailed(client=client, *args, **kwargs)

    class Page:
        def get(*args: Any, **kwargs: Any):
            client = set_client()

            return get_pages.sync_detailed(client=client, *args, **kwargs)

        def aget(*args: Any, **kwargs: Any):
            client = set_client()

            return get_pages.asyncio_detailed(client=client, *args, **kwargs)

        def delete(*args: Any, **kwargs: Any):
            client = set_client()

            return delete_page.sync_detailed(client=client, *args, **kwargs)

        def adelete(*args: Any, **kwargs: Any):
            client = set_client()

            return delete_page.asyncio_detailed(client=client, *args, **kwargs)

        def reindex(*args: Any, **kwargs: Any):
            client = set_client()

            return reindex_page.sync_detailed(client=client, *args, **kwargs)

        def areindex(*args: Any, **kwargs: Any):
            client = set_client()

            return reindex_page.asyncio_detailed(client=client, *args, **kwargs)

        def preview(*args: Any, **kwargs: Any):
            client = set_client()

            return preview_citation.sync_detailed(client=client, *args, **kwargs)

        def apreview(*args: Any, **kwargs: Any):
            client = set_client()

            return preview_citation.asyncio_detailed(client=client, *args, **kwargs)

    class PageMetadata:
        def get(*args: Any, **kwargs: Any):
            client = set_client()

            return get_metadata.sync_detailed(client=client, *args, **kwargs)

        def aget(*args: Any, **kwargs: Any):
            client = set_client()

            return get_metadata.asyncio_detailed(client=client, *args, **kwargs)

        def update(*args: Any, **kwargs: Any):
            client = set_client()
            fields = ["title", "url", "description", "image"]
            json = pluck_data(fields, kwargs)
            kwargs["json_body"] = UpdateMetadataJsonBody(**json)

            return update_metadata.sync_detailed(client=client, *args, **kwargs)

        def aupdate(*args: Any, **kwargs: Any):
            client = set_client()
            fields = ["title", "url", "description", "image"]
            json = pluck_data(fields, kwargs)
            kwargs["json_body"] = UpdateMetadataJsonBody(**json)

            return update_metadata.asyncio_detailed(client=client, *args, **kwargs)

    class ProjectSettings:
        def get(*args: Any, **kwargs: Any):
            client = set_client()

            return get_project_settings.sync_detailed(client=client, *args, **kwargs)

        def aget(*args: Any, **kwargs: Any):
            client = set_client()

            return get_project_settings.asyncio_detailed(client=client, *args, **kwargs)

        def update(*args: Any, **kwargs: Any):
            client = set_client()
            fields = [
                "chat_bot_avatar",
                "chat_bot_bg",
                "default_prompt",
                "example_questions",
                "response_source",
                "chatbot_msg_lang",
                "chatbot_color",
                "chatbot_toolbar_color",
                "persona_instructions",
                "citations_answer_source_label_msg",
                "citations_sources_label_msg",
                "hang_in_there_msg",
                "chatbot_siesta_msg",
                "is_loading_indicator_enabled",
                "enable_citations",
                "enable_feedbacks",
                "citations_view_type",
                "no_answer_message",
                "ending_message",
                "remove_branding",
                "enable_recaptcha_for_public_chatbots",
                "chatbot_model",
                "is_selling_enabled",
            ]
            json = pluck_data(fields, kwargs)
            kwargs["multipart_data"] = UpdateProjectSettingsMultipartData(**json)

            return update_project_settings.sync_detailed(client=client, *args, **kwargs)

        def aupdate(*args: Any, **kwargs: Any):
            client = set_client()
            fields = [
                "chat_bot_avatar",
                "chat_bot_bg",
                "default_prompt",
                "example_questions",
                "response_source",
                "chatbot_msg_lang",
                "chatbot_color",
                "chatbot_toolbar_color",
                "persona_instructions",
                "citations_answer_source_label_msg",
                "citations_sources_label_msg",
                "hang_in_there_msg",
                "chatbot_siesta_msg",
                "is_loading_indicator_enabled",
                "enable_citations",
                "enable_feedbacks",
                "citations_view_type",
                "no_answer_message",
                "ending_message",
                "remove_branding",
                "enable_recaptcha_for_public_chatbots",
                "chatbot_model",
                "is_selling_enabled",
            ]
            json = pluck_data(fields, kwargs)
            kwargs["multipart_data"] = UpdateProjectSettingsMultipartData(**json)

            return update_project_settings.asyncio_detailed(client=client, *args, **kwargs)

    class ProjectPlugins:
        def get(*args: Any, **kwargs: Any):
            client = set_client()

            return get_plugin.sync_detailed(client=client, *args, **kwargs)

        def aget(*args: Any, **kwargs: Any):
            client = set_client()

            return get_plugin.asyncio_detailed(client=client, *args, **kwargs)

        def update(*args: Any, **kwargs: Any):
            client = set_client()
            fields = ["model_name", "human_name", "keywords", "description", "is_active"]
            json = pluck_data(fields, kwargs)
            kwargs["json_body"] = UpdatePluginJsonBody(**json)

            return update_plugin.sync_detailed(client=client, *args, **kwargs)

        def aupdate(*args: Any, **kwargs: Any):
            client = set_client()
            fields = ["model_name", "human_name", "keywords", "description", "is_active"]
            json = pluck_data(fields, kwargs)
            kwargs["json_body"] = UpdatePluginJsonBody(**json)

            return update_plugin.asyncio_detailed(client=client, *args, **kwargs)

        def create(*args: Any, **kwargs: Any):
            client = set_client()
            fields = ["model_name", "human_name", "keywords", "description", "is_active"]
            json = pluck_data(fields, kwargs)
            kwargs["json_body"] = CreatePluginJsonBody(**json)

            return create_plugin.sync_detailed(client=client, *args, **kwargs)

        def acreate(*args: Any, **kwargs: Any):
            client = set_client()
            fields = ["model_name", "human_name", "keywords", "description", "is_active"]
            json = pluck_data(fields, kwargs)
            kwargs["json_body"] = CreatePluginJsonBody(**json)

            return create_plugin.asyncio_detailed(client=client, *args, **kwargs)

    class Conversation:
        def get(*args: Any, **kwargs: Any):
            client = set_client()

            return get_conversations.sync_detailed(client=client, *args, **kwargs)

        def aget(*args: Any, **kwargs: Any):
            client = set_client()

            return get_conversations.asyncio_detailed(client=client, *args, **kwargs)

        def create(*args: Any, **kwargs: Any):
            client = set_client()
            fields = ["name"]
            json = pluck_data(fields, kwargs)
            kwargs["json_body"] = CreateConversationJsonBody(**json)

            return create_conversation.sync_detailed(client=client, *args, **kwargs)

        def acreate(*args: Any, **kwargs: Any):
            client = set_client()
            fields = ["name"]
            json = pluck_data(fields, kwargs)
            kwargs["json_body"] = CreateConversationJsonBody(**json)

            return create_conversation.asyncio_detailed(client=client, *args, **kwargs)

        def update(*args: Any, **kwargs: Any):
            client = set_client()
            fields = ["name"]
            json = pluck_data(fields, kwargs)
            kwargs["json_body"] = UpdateConversationJsonBody(**json)

            return update_conversation.sync_detailed(client=client, *args, **kwargs)

        def aupdate(*args: Any, **kwargs: Any):
            client = set_client()
            fields = ["name"]
            json = pluck_data(fields, kwargs)
            kwargs["json_body"] = UpdateConversationJsonBody(**json)

            return update_conversation.asyncio_detailed(client=client, *args, **kwargs)

        def delete(*args: Any, **kwargs: Any):
            client = set_client()

            return delete_conversation.sync_detailed(client=client, *args, **kwargs)

        def adelete(*args: Any, **kwargs: Any):
            client = set_client()

            return delete_conversation.asyncio_detailed(client=client, *args, **kwargs)

        def messages(*args: Any, **kwargs: Any):
            client = set_client()

            return messages_conversation.sync_detailed(client=client, *args, **kwargs)

        def amessages(*args: Any, **kwargs: Any):
            client = set_client()

            return messages_conversation.asyncio_detailed(client=client, *args, **kwargs)

        def send(*args: Any, **kwargs: Any):
            client = set_client()
            fields = ["prompt", "custom_persona", "chatbot_model", "response_source"]
            json = pluck_data(fields, kwargs)
            kwargs["json_body"] = SendMessageJsonBody(**json)

            return send_message.sync_detailed(client=client, *args, **kwargs)

        def asend(*args: Any, **kwargs: Any):
            client = set_client()
            fields = ["prompt", "custom_persona", "chatbot_model", "response_source"]
            json = pluck_data(fields, kwargs)
            kwargs["json_body"] = SendMessageJsonBody(**json)

            return send_message.asyncio_detailed(client=client, *args, **kwargs)

    class Citation:
        def get(*args: Any, **kwargs: Any):
            client = set_client()

            return get_citation.sync_detailed(client=client, *args, **kwargs)

        def aget(*args: Any, **kwargs: Any):
            client = set_client()

            return get_citation.asyncio_detailed(client=client, *args, **kwargs)

    class Source:
        def list(*args: Any, **kwargs: Any):
            client = set_client()

            return list_sources.sync_detailed(client=client, *args, **kwargs)

        def alist(*args: Any, **kwargs: Any):
            client = set_client()

            return list_sources.asyncio_detailed(client=client, *args, **kwargs)

        def create(*args: Any, **kwargs: Any):
            client = set_client()
            fields = ["sitemap_path", "file_data_retension", "is_ocr_enabled", "is_anonymized", "file"]
            json = pluck_data(fields, kwargs)
            kwargs["multipart_data"] = CreateSourceMultipartData(**json)

            return create_source.sync_detailed(client=client, *args, **kwargs)

        def acreate(*args: Any, **kwargs: Any):
            client = set_client()
            fields = ["sitemap_path", "file_data_retension", "is_ocr_enabled", "is_anonymized", "file"]
            json = pluck_data(fields, kwargs)
            kwargs["multipart_data"] = CreateSourceMultipartData(**json)

            return create_source.asyncio_detailed(client=client, *args, **kwargs)

        def update(*args: Any, **kwargs: Any):
            client = set_client()
            fields = [
                "executive_js",
                "data_refresh_frequency",
                "create_new_pages",
                "remove_unexist_pages",
                "refresh_existing_pages",
                "refresh_schedule",
            ]
            json = pluck_data(fields, kwargs)
            kwargs["json_body"] = UpdateSourceJsonBody(**json)

            return update_source.sync_detailed(client=client, *args, **kwargs)

        def aupdate(*args: Any, **kwargs: Any):
            client = set_client()
            fields = [
                "executive_js",
                "data_refresh_frequency",
                "create_new_pages",
                "remove_unexist_pages",
                "refresh_existing_pages",
                "refresh_schedule",
            ]
            json = pluck_data(fields, kwargs)
            kwargs["json_body"] = UpdateSourceJsonBody(**json)

            return update_source.asyncio_detailed(client=client, *args, **kwargs)

        def delete(*args: Any, **kwargs: Any):
            client = set_client()

            return delete_source.sync_detailed(client=client, *args, **kwargs)

        def adelete(*args: Any, **kwargs: Any):
            client = set_client()

            return delete_source.asyncio_detailed(client=client, *args, **kwargs)

        def synchronize(*args: Any, **kwargs: Any):
            client = set_client()

            return synchronize_source.sync_detailed(client=client, *args, **kwargs)

        def asynchronize(*args: Any, **kwargs: Any):
            client = set_client()

            return synchronize_source.asyncio_detailed(client=client, *args, **kwargs)

    class ReportsAnalytics:
        def traffic(*args: Any, **kwargs: Any):
            client = set_client()

            return traffic_reports.sync_detailed(client=client, *args, **kwargs)

        def atraffic(*args: Any, **kwargs: Any):
            client = set_client()

            return traffic_reports.asyncio_detailed(client=client, *args, **kwargs)

        def queries(*args: Any, **kwargs: Any):
            client = set_client()

            return queries_reports.sync_detailed(client=client, *args, **kwargs)

        def aqueries(*args: Any, **kwargs: Any):
            client = set_client()

            return queries_reports.asyncio_detailed(client=client, *args, **kwargs)

        def conversations(*args: Any, **kwargs: Any):
            client = set_client()

            return conversations_reports.sync_detailed(client=client, *args, **kwargs)

        def aconversations(*args: Any, **kwargs: Any):
            client = set_client()

            return conversations_reports.asyncio_detailed(client=client, *args, **kwargs)

        def analysis(*args: Any, **kwargs: Any):
            client = set_client()

            return analysis_reports.sync_detailed(client=client, *args, **kwargs)

        def aanalysis(*args: Any, **kwargs: Any):
            client = set_client()

            return analysis_reports.asyncio_detailed(client=client, *args, **kwargs)

    class User:
        def get(*args: Any, **kwargs: Any):
            client = set_client()

            return get_user.sync_detailed(client=client, *args, **kwargs)

        def aget(*args: Any, **kwargs: Any):
            client = set_client()

            return get_user.asyncio_detailed(client=client, *args, **kwargs)

        def update(*args: Any, **kwargs: Any):
            client = set_client()
            fields = ["profile_photo", "name"]
            json = pluck_data(fields, kwargs)
            kwargs["multipart_data"] = UpdateUserMultipartData(**json)

            return update_user.sync_detailed(client=client, *args, **kwargs)

        def aupdate(*args: Any, **kwargs: Any):
            client = set_client()
            fields = ["profile_photo", "name"]
            json = pluck_data(fields, kwargs)
            kwargs["multipart_data"] = UpdateUserMultipartData(**json)

            return update_user.asyncio_detailed(client=client, *args, **kwargs)

    class Limit:
        def get(*args: Any, **kwargs: Any):
            client = set_client()

            return get_api_v1_limits_usage.sync_detailed(client=client, *args, **kwargs)

        def aget(*args: Any, **kwargs: Any):
            client = set_client()

            return get_api_v1_limits_usage.asyncio_detailed(client=client, *args, **kwargs)



from enum import Enum


class UpdateProjectSettingsMultipartDataChatbotMsgLang(str, Enum):
    AR = "ar"
    AZ = "az"
    BA = "ba"
    BE = "be"
    BG = "bg"
    BH = "bh"
    BN = "bn"
    BS = "bs"
    CA = "ca"
    CMN = "cmn"
    CS = "cs"
    CY = "cy"
    DA = "da"
    DE = "de"
    DOI = "doi"
    EL = "el"
    EN = "en"
    ES = "es"
    ET = "et"
    EU = "eu"
    FA = "fa"
    FI = "fi"
    FO = "fo"
    FR = "fr"
    GA = "ga"
    GL = "gl"
    GU = "gu"
    HE = "he"
    HI = "hi"
    HNE = "hne"
    HR = "hr"
    HRY = "hry"
    HU = "hu"
    HY = "hy"
    ID = "id"
    IT = "it"
    JA = "ja"
    JV = "jv"
    KA = "ka"
    KK = "kk"
    KN = "kn"
    KO = "ko"
    KOK = "kok"
    KS = "ks"
    KY = "ky"
    LT = "lt"
    LV = "lv"
    MAI = "mai"
    ME = "me"
    MK = "mk"
    MN = "mn"
    MO = "mo"
    MR = "mr"
    MS = "ms"
    MT = "mt"
    MWR = "mwr"
    NAN = "nan"
    NE = "ne"
    NL = "nl"
    NO = "no"
    OR = "or"
    PA = "pa"
    PL = "pl"
    PS = "ps"
    PT = "pt"
    PT_BR = "pt-BR"
    RAJ = "raj"
    RO = "ro"
    RU = "ru"
    SA = "sa"
    SAT = "sat"
    SD = "sd"
    SI = "si"
    SK = "sk"
    SL = "sl"
    SQ = "sq"
    SR = "sr"
    SV = "sv"
    SW = "sw"
    TA = "ta"
    TE = "te"
    TG = "tg"
    TH = "th"
    TK = "tk"
    TR = "tr"
    TT = "tt"
    UK = "uk"
    UR = "ur"
    UZ = "uz"
    VI = "vi"
    WUU = "wuu"
    YUE = "yue"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class GetProjectSettingsResponse200DataChatbotModel(str, Enum):
    GPT_3_5_TURBO = "gpt-3.5-turbo"
    GPT_4 = "gpt-4"
    GPT_4_O = "gpt-4-o"
    GPT_4_TURBO = "gpt-4-turbo"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class ProjectSettingsResponseSource(str, Enum):
    DEFAULT = "default"
    OPENAI_CONTENT = "openai_content"
    OWN_CONTENT = "own_content"

    def __str__(self) -> str:
        return str(self.value)
